[spell] Fix slew of spelling errors. (#13043)

* [spell] Fix slew of spelling errors.

* [spell] zap regen and restyle.

* [spell] Revert .github changes to pass restyle.
diff --git a/examples/all-clusters-app/mbed/main/main.cpp b/examples/all-clusters-app/mbed/main/main.cpp
index f92a5fa..830168b 100644
--- a/examples/all-clusters-app/mbed/main/main.cpp
+++ b/examples/all-clusters-app/mbed/main/main.cpp
@@ -48,7 +48,7 @@
     err = chip::Platform::MemoryInit();
     if (err != CHIP_NO_ERROR)
     {
-        ChipLogError(NotSpecified, "Memory initalization failed: %s", err.AsString());
+        ChipLogError(NotSpecified, "Memory initialization failed: %s", err.AsString());
         ret = EXIT_FAILURE;
         goto exit;
     }
@@ -56,7 +56,7 @@
     err = PlatformMgr().InitChipStack();
     if (err != CHIP_NO_ERROR)
     {
-        ChipLogError(NotSpecified, "Chip stack initalization failed: %s", err.AsString());
+        ChipLogError(NotSpecified, "Chip stack initialization failed: %s", err.AsString());
         ret = EXIT_FAILURE;
         goto exit;
     }
diff --git a/examples/chip-tool/commands/common/CHIPCommand.h b/examples/chip-tool/commands/common/CHIPCommand.h
index 54ef045..49fd213 100644
--- a/examples/chip-tool/commands/common/CHIPCommand.h
+++ b/examples/chip-tool/commands/common/CHIPCommand.h
@@ -85,7 +85,7 @@
     void SetIdentity(const char * name);
 
     // This method returns the commissioner instance to be used for running the command.
-    // The default commissioner instance name is "alpha", but it can be overriden by passing
+    // The default commissioner instance name is "alpha", but it can be overridden by passing
     // --identity "instance name" when running a command.
     ChipDeviceCommissioner & CurrentCommissioner();
 
diff --git a/examples/chip-tool/commands/discover/DiscoverCommissionersCommand.cpp b/examples/chip-tool/commands/discover/DiscoverCommissionersCommand.cpp
index 23e9b47..a1d2ad1 100644
--- a/examples/chip-tool/commands/discover/DiscoverCommissionersCommand.cpp
+++ b/examples/chip-tool/commands/discover/DiscoverCommissionersCommand.cpp
@@ -34,7 +34,7 @@
         const Dnssd::DiscoveredNodeData * commissioner = mCommissionableNodeController.GetDiscoveredCommissioner(i);
         if (commissioner != nullptr)
         {
-            ChipLogProgress(chipTool, "Discovered Commisioner #%d", commissionerCount);
+            ChipLogProgress(chipTool, "Discovered Commissioner #%d", commissionerCount);
             commissioner->LogDetail();
             commissionerCount++;
         }
diff --git a/examples/ipv6only-app/esp32/include/wifi_service.h b/examples/ipv6only-app/esp32/include/wifi_service.h
index b2db2e1..bac3129 100644
--- a/examples/ipv6only-app/esp32/include/wifi_service.h
+++ b/examples/ipv6only-app/esp32/include/wifi_service.h
@@ -40,7 +40,7 @@
     // Initalize the wifi station
     pw::Status Init();
 
-    // Blocks the calling thread until wifi connection is completed succesfully.
+    // Blocks the calling thread until wifi connection is completed successfully.
     // NOTE: Currently only supports blocking a single thread.
     void BlockUntilWifiConnected() { xSemaphoreTake(wifi_connected_semaphore_, portMAX_DELAY); }
 
diff --git a/examples/ipv6only-app/esp32/main/wifi_service.cpp b/examples/ipv6only-app/esp32/main/wifi_service.cpp
index 17935a4..1795d4d 100644
--- a/examples/ipv6only-app/esp32/main/wifi_service.cpp
+++ b/examples/ipv6only-app/esp32/main/wifi_service.cpp
@@ -42,7 +42,7 @@
 
 // Class handles the event handlers needed for station startup.
 // Creating the object will register all handlers needed, destroying will
-// unregister. The object is only needed during initalization, after the station
+// unregister. The object is only needed during initialization, after the station
 // is up it is safe to destroy this object.
 class WifiInitStationEventHandler
 {
@@ -114,7 +114,7 @@
         vEventGroupDelete(handler_context_.event_group);
     }
 
-    // Waits for the events to determine if connected succesfully.
+    // Waits for the events to determine if connected successfully.
     pw::Status WaitForConnection(chip_rpc_ConnectionResult * result)
     {
         EventBits_t bits = xEventGroupWaitBits(handler_context_.event_group, kWifiFailBit | kWifiIpv6ConnectedBit, pdFALSE, pdFALSE,
diff --git a/examples/lighting-app/mbed/main/main.cpp b/examples/lighting-app/mbed/main/main.cpp
index 4c99ea3..8d9ad2c 100644
--- a/examples/lighting-app/mbed/main/main.cpp
+++ b/examples/lighting-app/mbed/main/main.cpp
@@ -71,7 +71,7 @@
     err = chip::Platform::MemoryInit();
     if (err != CHIP_NO_ERROR)
     {
-        ChipLogError(NotSpecified, "Memory initalization failed: %s", err.AsString());
+        ChipLogError(NotSpecified, "Memory initialization failed: %s", err.AsString());
         ret = EXIT_FAILURE;
         goto exit;
     }
@@ -79,7 +79,7 @@
     err = PlatformMgr().InitChipStack();
     if (err != CHIP_NO_ERROR)
     {
-        ChipLogError(NotSpecified, "Chip stack initalization failed: %s", err.AsString());
+        ChipLogError(NotSpecified, "Chip stack initialization failed: %s", err.AsString());
         ret = EXIT_FAILURE;
         goto exit;
     }
diff --git a/examples/lighting-app/nxp/k32w/k32w0/args.gni b/examples/lighting-app/nxp/k32w/k32w0/args.gni
index 9e95d3b..0f92175 100644
--- a/examples/lighting-app/nxp/k32w/k32w0/args.gni
+++ b/examples/lighting-app/nxp/k32w/k32w0/args.gni
@@ -15,5 +15,5 @@
 import("//build_overrides/chip.gni")
 import("${chip_root}/examples/platform/nxp/k32w/k32w0/args.gni")
 
-# SDK target. This is overriden to add our SDK app_config.h & defines.
+# SDK target. This is overridden to add our SDK app_config.h & defines.
 k32w0_sdk_target = get_label_info(":sdk", "label_no_toolchain")
diff --git a/examples/lock-app/mbed/main/main.cpp b/examples/lock-app/mbed/main/main.cpp
index e527ade..349d9ac 100644
--- a/examples/lock-app/mbed/main/main.cpp
+++ b/examples/lock-app/mbed/main/main.cpp
@@ -71,7 +71,7 @@
     err = chip::Platform::MemoryInit();
     if (err != CHIP_NO_ERROR)
     {
-        ChipLogError(NotSpecified, "Memory initalization failed: %s", err.AsString());
+        ChipLogError(NotSpecified, "Memory initialization failed: %s", err.AsString());
         ret = EXIT_FAILURE;
         goto exit;
     }
@@ -79,7 +79,7 @@
     err = PlatformMgr().InitChipStack();
     if (err != CHIP_NO_ERROR)
     {
-        ChipLogError(NotSpecified, "Chip stack initalization failed: %s", err.AsString());
+        ChipLogError(NotSpecified, "Chip stack initialization failed: %s", err.AsString());
         ret = EXIT_FAILURE;
         goto exit;
     }
diff --git a/examples/lock-app/nxp/k32w/k32w0/args.gni b/examples/lock-app/nxp/k32w/k32w0/args.gni
index 9e95d3b..0f92175 100644
--- a/examples/lock-app/nxp/k32w/k32w0/args.gni
+++ b/examples/lock-app/nxp/k32w/k32w0/args.gni
@@ -15,5 +15,5 @@
 import("//build_overrides/chip.gni")
 import("${chip_root}/examples/platform/nxp/k32w/k32w0/args.gni")
 
-# SDK target. This is overriden to add our SDK app_config.h & defines.
+# SDK target. This is overridden to add our SDK app_config.h & defines.
 k32w0_sdk_target = get_label_info(":sdk", "label_no_toolchain")
diff --git a/examples/platform/efr32/uart.cpp b/examples/platform/efr32/uart.cpp
index 0fed6bd..9d3cbc2 100644
--- a/examples/platform/efr32/uart.cpp
+++ b/examples/platform/efr32/uart.cpp
@@ -97,7 +97,7 @@
     // if equal there is no data return 0 directly
     if (fifo->Tail != fifo->Head)
     {
-        // determine if a wrap around occured to get the right data size avalaible.
+        // determine if a wrap around occurred to get the right data size avalaible.
         size = (fifo->Tail < fifo->Head) ? (fifo->MaxSize - fifo->Head + fifo->Tail) : (fifo->Tail - fifo->Head);
     }
 
diff --git a/examples/shell/mbed/main/main.cpp b/examples/shell/mbed/main/main.cpp
index 7865283..1ab85f2 100644
--- a/examples/shell/mbed/main/main.cpp
+++ b/examples/shell/mbed/main/main.cpp
@@ -48,7 +48,7 @@
     err = chip::Platform::MemoryInit();
     if (err != CHIP_NO_ERROR)
     {
-        ChipLogError(Shell, "Memory initalization failed: %s", err.AsString());
+        ChipLogError(Shell, "Memory initialization failed: %s", err.AsString());
         ret = EXIT_FAILURE;
         goto exit;
     }
@@ -56,7 +56,7 @@
     err = PlatformMgr().InitChipStack();
     if (err != CHIP_NO_ERROR)
     {
-        ChipLogError(Shell, "Chip stack initalization failed: %s", err.AsString());
+        ChipLogError(Shell, "Chip stack initialization failed: %s", err.AsString());
         ret = EXIT_FAILURE;
         goto exit;
     }
diff --git a/examples/tv-app/android/java/src/com/tcl/chip/tvapp/MediaPlaybackManager.java b/examples/tv-app/android/java/src/com/tcl/chip/tvapp/MediaPlaybackManager.java
index abfb803..7972a49 100755
--- a/examples/tv-app/android/java/src/com/tcl/chip/tvapp/MediaPlaybackManager.java
+++ b/examples/tv-app/android/java/src/com/tcl/chip/tvapp/MediaPlaybackManager.java
@@ -115,7 +115,7 @@
   long getAttributes(int attributesId);
 
   /**
-   * Request for cmd in REQUEST_XXX, the paramters for request is defined in REQUEST_XXX
+   * Request for cmd in REQUEST_XXX, the parameters for request is defined in REQUEST_XXX
    *
    * @param parameter The means of parameter is defined in RESPONSE_STATUS_XXX or meaningless if not
    *     defined.
diff --git a/scripts/helpers/bloat_check.py b/scripts/helpers/bloat_check.py
index db11570..def2892 100755
--- a/scripts/helpers/bloat_check.py
+++ b/scripts/helpers/bloat_check.py
@@ -111,7 +111,7 @@
                         baselineDir,
                         buildOutputDir,
                         title='BLOAT REPORT'):
-    """Generates a bloat report fo files betwen two diferent directories."""
+    """Generates a bloat report fo files between two diferent directories."""
     logging.info('Generating bloat diff report between %s and %s', baselineDir,
                  buildOutputDir)
     with open(outputFileName, 'wt') as f:
diff --git a/scripts/tools/linux_ip_namespace_setup.sh b/scripts/tools/linux_ip_namespace_setup.sh
index 1520efe..5d467b4 100755
--- a/scripts/tools/linux_ip_namespace_setup.sh
+++ b/scripts/tools/linux_ip_namespace_setup.sh
@@ -116,7 +116,7 @@
     echo "between a controller and device on the same linux machine."
     echo ""
     echo "To use this script, run the device code in a namespace using the -r command"
-    echo "and a controller in a seperate terminal to simulate two devices communicating"
+    echo "and a controller in a separate terminal to simulate two devices communicating"
     echo "across a network."
     echo "Example:"
     echo "--------"
diff --git a/src/app/CASEClient.cpp b/src/app/CASEClient.cpp
index 24c79ae..7fc9248 100644
--- a/src/app/CASEClient.cpp
+++ b/src/app/CASEClient.cpp
@@ -66,7 +66,7 @@
 
 void CASEClient::OnSessionEstablished()
 {
-    // On successfull CASE connection, the local session ID will be used for the derived secure session.
+    // On successful CASE connection, the local session ID will be used for the derived secure session.
     if (mConnectionSuccessCallback)
     {
         mConnectionSuccessCallback(mConectionContext, this);
diff --git a/src/app/CommandSender.h b/src/app/CommandSender.h
index 464e0c2..8409694 100644
--- a/src/app/CommandSender.h
+++ b/src/app/CommandSender.h
@@ -97,7 +97,7 @@
         {}
 
         /**
-         * OnError will be called when an error occurr *after* a successful call to SendCommandRequest(). The following
+         * OnError will be called when an error occur *after* a successful call to SendCommandRequest(). The following
          * errors will be delivered through this call in the aError field:
          *
          * - CHIP_ERROR_TIMEOUT: A response was not received within the expected response timeout.
@@ -117,7 +117,7 @@
         virtual void OnError(const CommandSender * apCommandSender, const StatusIB & aStatusIB, CHIP_ERROR aError) {}
 
         /**
-         * OnDone will be called when CommandSender has finished all work and is safe to destory and free the
+         * OnDone will be called when CommandSender has finished all work and is safe to destroy and free the
          * allocated CommandSender object.
          *
          * This function will:
@@ -202,7 +202,7 @@
     // Upon successful return from this call, all subsequent errors that occur during this interaction
     // will be conveyed through the OnError callback above. In addition, upon completion of work regardless of
     // whether it was successful or not, the OnDone callback will be invoked to indicate completion of work on this
-    // object and to indicate to the application that it can destory and free this object.
+    // object and to indicate to the application that it can destroy and free this object.
     //
     // Applications can, however, destroy this object at any time after this call, except while handling
     // an OnResponse or OnError callback, and it will safely clean-up.
diff --git a/src/app/InteractionModelEngine.cpp b/src/app/InteractionModelEngine.cpp
index 1ebfbdb..b4cddea 100644
--- a/src/app/InteractionModelEngine.cpp
+++ b/src/app/InteractionModelEngine.cpp
@@ -18,7 +18,7 @@
 
 /**
  *    @file
- *      This file defines objects for a CHIP Interaction Data model Engine which handle unsolicitied IM message, and
+ *      This file defines objects for a CHIP Interaction Data model Engine which handle unsolicited IM message, and
  *      manage different kinds of IM client and handlers.
  *
  */
diff --git a/src/app/InteractionModelEngine.h b/src/app/InteractionModelEngine.h
index 9597458..3b279f4 100644
--- a/src/app/InteractionModelEngine.h
+++ b/src/app/InteractionModelEngine.h
@@ -18,7 +18,7 @@
 
 /**
  *    @file
- *      This file defines objects for a CHIP Interaction Data model Engine which handle unsolicitied IM message, and
+ *      This file defines objects for a CHIP Interaction Data model Engine which handle unsolicited IM message, and
  *      manage different kinds of IM client and handlers.
  *
  */
diff --git a/src/app/clusters/color-control-server/color-control-server.cpp b/src/app/clusters/color-control-server/color-control-server.cpp
index 2e5752f..811992b 100644
--- a/src/app/clusters/color-control-server/color-control-server.cpp
+++ b/src/app/clusters/color-control-server/color-control-server.cpp
@@ -427,7 +427,7 @@
 }
 
 /**
- * @brief Return difference betwen two hues.
+ * @brief Return difference between two hues.
  *
  * @param hue1
  * @param hue2
@@ -2065,7 +2065,7 @@
     // the StartUpColorTemperatureMireds attribute are listed in the table below.
     // Value                Action on power up
     // 0x0000-0xffef        Set the ColorTemperatureMireds attribute to this value.
-    // 0xffff               Set the ColorTemperatureMireds attribue to its previous value.
+    // 0xffff               Set the ColorTemperatureMireds attribute to its previous value.
 
     // Initialize startUpColorTempMireds to "maintain previous value" value 0xFFFF
     uint16_t startUpColorTemp = 0xFFFF;
diff --git a/src/app/clusters/color-control-server/color-control-server.h b/src/app/clusters/color-control-server/color-control-server.h
index 6c3a90d..7ce355d 100644
--- a/src/app/clusters/color-control-server/color-control-server.h
+++ b/src/app/clusters/color-control-server/color-control-server.h
@@ -234,7 +234,7 @@
 #endif // EMBER_AF_PLUGIN_COLOR_CONTROL_SERVER_TEMP
 
     /**********************************************************
-     * Attributes Decleration
+     * Attributes Declaration
      *********************************************************/
     static ColorControlServer instance;
 
diff --git a/src/app/clusters/ias-zone-server/ias-zone-server.cpp b/src/app/clusters/ias-zone-server/ias-zone-server.cpp
index ab7f33f..82f9d36 100644
--- a/src/app/clusters/ias-zone-server/ias-zone-server.cpp
+++ b/src/app/clusters/ias-zone-server/ias-zone-server.cpp
@@ -801,7 +801,7 @@
     // If a change status change notification command is not received by the
     // client, delay the option specified amount of time and try to resend it.
     // The event handler will perform the retransmit per the preset queue retry
-    // parameteres, and the original send request will handle populating the buffer.
+    // parameters, and the original send request will handle populating the buffer.
     // Do not try to retransmit again if the maximum number of retries attempts
     // is reached, this is however discarded if configured for unlimited retries.
     if ((status == EMBER_DELIVERY_FAILED) &&
diff --git a/src/app/clusters/mode-select-server/supported-modes-manager.h b/src/app/clusters/mode-select-server/supported-modes-manager.h
index 4fb5bfb..c774688 100644
--- a/src/app/clusters/mode-select-server/supported-modes-manager.h
+++ b/src/app/clusters/mode-select-server/supported-modes-manager.h
@@ -73,7 +73,7 @@
      * @param endpointId The endpoint for which to search the ModeOptionStruct.
      * @param mode The mode for which to search the ModeOptionStruct.
      * @param dataPtr The pointer to receive the ModeOptionStruct, if one is found.
-     * @return EMBER_ZCL_STATUS_SUCCESS if sucessfully found the option. Otherwise, returns appropriate status code (found in
+     * @return EMBER_ZCL_STATUS_SUCCESS if successfully found the option. Otherwise, returns appropriate status code (found in
      * <app/util/af-enums.h>)
      */
     virtual EmberAfStatus getModeOptionByMode(EndpointId endpointId, uint8_t mode, const ModeOptionStructType ** dataPtr) const = 0;
diff --git a/src/app/clusters/on-off-server/on-off-server.cpp b/src/app/clusters/on-off-server/on-off-server.cpp
index 684a30d..d844739 100644
--- a/src/app/clusters/on-off-server/on-off-server.cpp
+++ b/src/app/clusters/on-off-server/on-off-server.cpp
@@ -179,7 +179,7 @@
 
 #ifdef EMBER_AF_PLUGIN_SCENES
     // the scene has been changed (the value of on/off has changed) so
-    // the current scene as descibed in the attribute table is invalid,
+    // the current scene as described in the attribute table is invalid,
     // so mark it as invalid (just writes the valid/invalid attribute)
     if (emberAfContainsServer(endpoint, Scenes::Id))
     {
diff --git a/src/app/clusters/on-off-server/on-off-server.h b/src/app/clusters/on-off-server/on-off-server.h
index fa402be..4e3c6ef 100644
--- a/src/app/clusters/on-off-server/on-off-server.h
+++ b/src/app/clusters/on-off-server/on-off-server.h
@@ -69,7 +69,7 @@
     EmberEventControl * configureEventControl(chip::EndpointId endpoint);
 
     /**********************************************************
-     * Attributes Decleration
+     * Attributes Declaration
      *********************************************************/
 
     static OnOffServer instance;
@@ -92,7 +92,7 @@
 
         /*
          * effectVariant's type depends on the effect effectIdentifier so we don't know the type at compile time.
-         * Casting to uint8_t for more flexibilty since the type can be OnOffDelayedAllOffEffectVariant or
+         * Casting to uint8_t for more flexibility since the type can be OnOffDelayedAllOffEffectVariant or
          * OnOffDelayedAllOffEffectVariant
          */
         uint8_t effectVariant = static_cast<uint8_t>(EMBER_ZCL_ON_OFF_DELAYED_ALL_OFF_EFFECT_VARIANT_FADE_TO_OFF_IN_0P8_SECONDS));
diff --git a/src/app/clusters/zll-on-off-server/zll-on-off-server.c b/src/app/clusters/zll-on-off-server/zll-on-off-server.c
index aab25f9..dcfe2fb 100644
--- a/src/app/clusters/zll-on-off-server/zll-on-off-server.c
+++ b/src/app/clusters/zll-on-off-server/zll-on-off-server.c
@@ -175,7 +175,7 @@
     bool globalSceneControl;
     uint8_t endpoint = emberAfCurrentEndpoint();
 
-    // Ensure parameters have values withing proper range.
+    // Ensure parameters have values within proper range.
     if (effectId > EMBER_ZCL_ON_OFF_EFFECT_IDENTIFIER_DYING_LIGHT ||
         effectVariant >
             EMBER_ZCL_ON_OFF_DELAYED_ALL_OFF_EFFECT_VARIANT_50_PERCENT_DIM_DOWN_IN_0P8_SECONDS_THEN_FADE_TO_OFF_IN_12_SECONDS ||
diff --git a/src/app/tests/suites/certification/Test_TC_CC_8_1.yaml b/src/app/tests/suites/certification/Test_TC_CC_8_1.yaml
index eac71c1..34e4a4f 100644
--- a/src/app/tests/suites/certification/Test_TC_CC_8_1.yaml
+++ b/src/app/tests/suites/certification/Test_TC_CC_8_1.yaml
@@ -34,7 +34,7 @@
       response:
           value: 1
 
-    - label: "Color Loop Set Command - Set all Attributs"
+    - label: "Color Loop Set Command - Set all Attributes"
       command: "ColorLoopSet"
       arguments:
           values:
diff --git a/src/app/tests/suites/certification/Test_TC_RH_1_1.yaml b/src/app/tests/suites/certification/Test_TC_RH_1_1.yaml
index abdb31a..2344af1 100644
--- a/src/app/tests/suites/certification/Test_TC_RH_1_1.yaml
+++ b/src/app/tests/suites/certification/Test_TC_RH_1_1.yaml
@@ -24,7 +24,7 @@
       command: "WaitForCommissionee"
 
     #issue #12190 as per spec default value is 3 but expecting 2
-    #refering default value of Water Content Measurement
+    #referring default value of Water Content Measurement
     - label: "read the global attribute: ClusterRevision"
       disabled: true
       command: "readAttribute"
diff --git a/src/app/tests/suites/certification/Test_TC_TSTAT_2_2.yaml b/src/app/tests/suites/certification/Test_TC_TSTAT_2_2.yaml
index 5b502b3..8846dfd 100644
--- a/src/app/tests/suites/certification/Test_TC_TSTAT_2_2.yaml
+++ b/src/app/tests/suites/certification/Test_TC_TSTAT_2_2.yaml
@@ -54,7 +54,7 @@
       response:
           value: 2000
 
-    #issue #11718 Write command above max and below min value returns Sucess Response
+    #issue #11718 Write command above max and below min value returns Success Response
     - label:
           "Writes OccupiedCoolingSetpoint to value below the
           MinCoolSetpointLimit"
@@ -65,7 +65,7 @@
       arguments:
           value: 30
 
-    #issue  #11718 Write command above max and below min value returns Sucess Response
+    #issue  #11718 Write command above max and below min value returns Success Response
     - label:
           "Writes OccupiedCoolingSetpoint to value above the
           MaxCoolSetpointLimit"
@@ -125,7 +125,7 @@
       response:
           value: 2100
 
-    #issue  #11718 Write command above max and below min value returns Sucess Response
+    #issue  #11718 Write command above max and below min value returns Success Response
     - label:
           "Writes OccupiedHeatingSetpoint to value below the
           MinHeatSetpointLimit"
@@ -136,7 +136,7 @@
       arguments:
           value: 1002
 
-    #issue  #11718 Write command above max and below min value returns Sucess Response
+    #issue  #11718 Write command above max and below min value returns Success Response
     - label:
           "Writes OccupiedHeatingSetpoint to value above the
           MaxHeatSetpointLimit"
@@ -196,7 +196,7 @@
       response:
           value: 2000
 
-    #issue  #11718 Write command above max and below min value returns Sucess Response
+    #issue  #11718 Write command above max and below min value returns Success Response
     - label:
           "Writes MinHeatSetpointLimit to value below the
           AbsMinHeatSetpointLimit "
@@ -207,7 +207,7 @@
       arguments:
           value: 650
 
-    #issue  #11718 Write command above max and below min value returns Sucess Response
+    #issue  #11718 Write command above max and below min value returns Success Response
     - label:
           "Writes MinHeatSetpointLimit to value above the
           AbsMaxHeatSetpointLimit "
@@ -267,7 +267,7 @@
       response:
           value: 2000
 
-    #issue  #11718 Write command above max and below min value returns Sucess Response
+    #issue  #11718 Write command above max and below min value returns Success Response
     - label:
           "Writes MaxHeatSetpointLimit to value below the
           AbsMinHeatSetpointLimit "
@@ -278,7 +278,7 @@
       arguments:
           value: 500
 
-    #issue  #11718 Write command above max and below min value returns Sucess Response
+    #issue  #11718 Write command above max and below min value returns Success Response
     - label:
           "Writes MaxHeatSetpointLimit to value above the
           AbsMaxHeatSetpointLimit "
@@ -338,7 +338,7 @@
       response:
           value: 2000
 
-    #issue #11718 Write command above max and below min value returns Sucess Response
+    #issue #11718 Write command above max and below min value returns Success Response
     - label:
           "Writes MinCoolSetpointLimit to value below the
           AbsMinCoolSetpointLimit "
@@ -349,7 +349,7 @@
       arguments:
           value: 1000
 
-    #issue #11718 Write command above max and below min value returns Sucess Response
+    #issue #11718 Write command above max and below min value returns Success Response
     - label:
           "Writes MinCoolSetpointLimit to value above the MaxCoolSetpointLimit "
       disabled: true
@@ -408,7 +408,7 @@
       response:
           value: 2000
 
-    #issue  #11718 Write command above max and below min value returns Sucess Response
+    #issue  #11718 Write command above max and below min value returns Success Response
     - label:
           "Writes MaxCoolSetpointLimit to value below the
           AbsMinCoolSetpointLimit "
@@ -419,7 +419,7 @@
       arguments:
           value: 1000
 
-    #issue  #11718 Write command above max and below min value returns Sucess Response
+    #issue  #11718 Write command above max and below min value returns Success Response
     - label:
           "Writes MaxCoolSetpointLimit to value above the MaxCoolSetpointLimit "
       disabled: true
diff --git a/src/app/util/MatterCallbacks.h b/src/app/util/MatterCallbacks.h
index 806c07c..3150f87 100644
--- a/src/app/util/MatterCallbacks.h
+++ b/src/app/util/MatterCallbacks.h
@@ -34,6 +34,6 @@
 /** @brief Matter Post Command Received
  *
  * This callback is called once the message has been determined to be a command, but
- * after it beeing dispatched to the receiver.
+ * after it being dispatched to the receiver.
  */
 void MatterPostCommandReceivedCallback(const chip::app::ConcreteCommandPath & commandPath);
diff --git a/src/app/zap-templates/templates/app/CHIPClientCallbacks-src.zapt b/src/app/zap-templates/templates/app/CHIPClientCallbacks-src.zapt
index 9cb96ce..4e07abd 100644
--- a/src/app/zap-templates/templates/app/CHIPClientCallbacks-src.zapt
+++ b/src/app/zap-templates/templates/app/CHIPClientCallbacks-src.zapt
@@ -115,7 +115,7 @@
     }
 
 
-{{! TODO: These IM related callbacks contains small or no generated code, should be put into seperate file to reduce the size of template. }}
+{{! TODO: These IM related callbacks contains small or no generated code, should be put into separate file to reduce the size of template. }}
 
 // Singleton instance of the callbacks manager
 app::CHIPDeviceCallbacksMgr & gCallbacks = app::CHIPDeviceCallbacksMgr::GetInstance();
diff --git a/src/app/zap-templates/zcl/data-model/chip/general-commissioning-cluster.xml b/src/app/zap-templates/zcl/data-model/chip/general-commissioning-cluster.xml
index b57c7b0..02c6960 100644
--- a/src/app/zap-templates/zcl/data-model/chip/general-commissioning-cluster.xml
+++ b/src/app/zap-templates/zcl/data-model/chip/general-commissioning-cluster.xml
@@ -67,7 +67,7 @@
       <arg name="debugText" type="CHAR_STRING"/>
     </command>
     <command source="client" code="0x04" name="CommissioningComplete" optional="false" cli="chip fabric_commissioning commissioningcomplete">
-      <description>Signals the Commissionee that the Commissioner has sucessfully completed all steps of commissioning</description>
+      <description>Signals the Commissionee that the Commissioner has successfully completed all steps of commissioning</description>
     </command>
     <command source="server" code="0x05" name="CommissioningCompleteResponse" optional="false" cli="chip fabric_commissioning commissioningcompleteresponse">
       <description>Sender expects CommissioningCompleteResponse command if the CommissioningComplete command was correctly received</description>
diff --git a/src/ble/BLEEndPoint.cpp b/src/ble/BLEEndPoint.cpp
index 2cfb380..7b05ea8 100644
--- a/src/ble/BLEEndPoint.cpp
+++ b/src/ble/BLEEndPoint.cpp
@@ -85,7 +85,7 @@
  *
  *  @brief
  *    This is amount of time, in milliseconds, which a BLE end point will wait for an unsubscribe operation to complete
- *    before it automatically releases its BLE connection and frees itself. The default value of 5 seconds is arbitary.
+ *    before it automatically releases its BLE connection and frees itself. The default value of 5 seconds is arbitrary.
  *
  */
 #define BLE_UNSUBSCRIBE_TIMEOUT_MS                            5000 // 5 seconds
diff --git a/src/ble/BLEEndPoint.h b/src/ble/BLEEndPoint.h
index b36748d..e5ed023 100644
--- a/src/ble/BLEEndPoint.h
+++ b/src/ble/BLEEndPoint.h
@@ -153,7 +153,7 @@
     // connection is established.
     PacketBufferHandle mSendQueue;
 
-    // Pending stand-alone BTP acknolwedgement. Pre-empts regular send queue or fragmented message transmission in
+    // Pending stand-alone BTP acknowledgement. Pre-empts regular send queue or fragmented message transmission in
     // progress.
     PacketBufferHandle mAckToSend;
 
diff --git a/src/ble/BleApplicationDelegate.h b/src/ble/BleApplicationDelegate.h
index 04084cd..542e46b 100644
--- a/src/ble/BleApplicationDelegate.h
+++ b/src/ble/BleApplicationDelegate.h
@@ -39,7 +39,7 @@
 
     // CHIP calls this function once it closes the last BLEEndPoint associated with a BLE given connection object.
     // A call to this function means CHIP no longer cares about the state of the given BLE connection.
-    // The application can use this callback to e.g. close the underlying BLE conection if it is no longer needed,
+    // The application can use this callback to e.g. close the underlying BLE connection if it is no longer needed,
     // decrement the connection's refcount if it has one, or perform any other sort of cleanup as desired.
     virtual void NotifyChipConnectionClosed(BLE_CONNECTION_OBJECT connObj) = 0;
 };
diff --git a/src/ble/BleLayer.h b/src/ble/BleLayer.h
index efe2703..cbef971 100644
--- a/src/ble/BleLayer.h
+++ b/src/ble/BleLayer.h
@@ -246,8 +246,8 @@
 
     CHIP_ERROR CancelBleIncompleteConnection();
     CHIP_ERROR NewBleConnectionByDiscriminator(uint16_t connDiscriminator, void * appState = nullptr,
-                                               BleConnectionDelegate::OnConnectionCompleteFunct onSucess = OnConnectionComplete,
-                                               BleConnectionDelegate::OnConnectionErrorFunct onError     = OnConnectionError);
+                                               BleConnectionDelegate::OnConnectionCompleteFunct onSuccess = OnConnectionComplete,
+                                               BleConnectionDelegate::OnConnectionErrorFunct onError      = OnConnectionError);
     CHIP_ERROR NewBleConnectionByObject(BLE_CONNECTION_OBJECT connObj);
     CHIP_ERROR NewBleEndPoint(BLEEndPoint ** retEndPoint, BLE_CONNECTION_OBJECT connObj, BleRole role, bool autoClose);
 
@@ -298,7 +298,7 @@
     /// Call when an outstanding GATT write request receives a positive receipt confirmation.
     bool HandleWriteConfirmation(BLE_CONNECTION_OBJECT connObj, const ChipBleUUID * svcId, const ChipBleUUID * charId);
 
-    /// Call when an oustanding GATT indication receives a positive receipt confirmation.
+    /// Call when an outstanding GATT indication receives a positive receipt confirmation.
     bool HandleIndicationConfirmation(BLE_CONNECTION_OBJECT connObj, const ChipBleUUID * svcId, const ChipBleUUID * charId);
 
     /// Call when a GATT read request is received.
diff --git a/src/ble/BtpEngine.cpp b/src/ble/BtpEngine.cpp
index a9882ee..aeba267 100644
--- a/src/ble/BtpEngine.cpp
+++ b/src/ble/BtpEngine.cpp
@@ -182,10 +182,10 @@
     {
         mTxOldestUnackedSeqNum = ack_num;
 
-        // All oustanding fragments have been acknowledged.
+        // All outstanding fragments have been acknowledged.
         mExpectingAck = false;
     }
-    else // If ack is valid, but not for newest oustanding unacknowledged fragment...
+    else // If ack is valid, but not for newest outstanding unacknowledged fragment...
     {
         // Update newest unacknowledged fragment to one past that which was just acknowledged.
         mTxOldestUnackedSeqNum = ack_num;
@@ -196,7 +196,7 @@
 }
 
 // Calling convention:
-//   EncodeStandAloneAck may only be called if data arg is commited for immediate, synchronous subsequent transmission.
+//   EncodeStandAloneAck may only be called if data arg is committed for immediate, synchronous subsequent transmission.
 CHIP_ERROR BtpEngine::EncodeStandAloneAck(const PacketBufferHandle & data)
 {
     // Ensure enough headroom exists for the lower BLE layers.
@@ -412,7 +412,7 @@
 }
 
 // Calling convention:
-//   May only be called if data arg is commited for immediate, synchronous subsequent transmission.
+//   May only be called if data arg is committed for immediate, synchronous subsequent transmission.
 //   Returns false on error. Caller must free data arg on error.
 bool BtpEngine::HandleCharacteristicSend(System::PacketBufferHandle data, bool send_ack)
 {
diff --git a/src/controller/CHIPDeviceController.cpp b/src/controller/CHIPDeviceController.cpp
index d69df2c..c4e2a4f 100644
--- a/src/controller/CHIPDeviceController.cpp
+++ b/src/controller/CHIPDeviceController.cpp
@@ -1182,7 +1182,7 @@
         {
             ChipLogError(Controller,
                          "Failed in verifying 'Attestation Information' command received from the device due to default "
-                         "DeviceAttestationVerifier Class not being overriden by a real implementation.");
+                         "DeviceAttestationVerifier Class not being overridden by a real implementation.");
             return CHIP_ERROR_NOT_IMPLEMENTED;
         }
         else
diff --git a/src/controller/CHIPDeviceController.h b/src/controller/CHIPDeviceController.h
index eddef1f..d4d2652 100644
--- a/src/controller/CHIPDeviceController.h
+++ b/src/controller/CHIPDeviceController.h
@@ -200,7 +200,7 @@
      *  grab the CHIP stack lock.
      *
      *  This will also not stop the CHIP event queue / thread (if one exists).  Consumers are expected to
-     *  ensure this happend before calling this method.
+     *  ensure this happened before calling this method.
      */
     virtual CHIP_ERROR Shutdown();
 
@@ -697,22 +697,22 @@
      */
     CHIP_ERROR SendAttestationRequestCommand(CommissioneeDeviceProxy * device, const ByteSpan & attestationNonce);
     /* This function sends an OpCSR request to the device.
-       The function does not hold a refernce to the device object.
+       The function does not hold a reference to the device object.
      */
     CHIP_ERROR SendOperationalCertificateSigningRequestCommand(CommissioneeDeviceProxy * device);
     /* This function sends the operational credentials to the device.
-       The function does not hold a refernce to the device object.
+       The function does not hold a reference to the device object.
      */
     CHIP_ERROR SendOperationalCertificate(CommissioneeDeviceProxy * device, const ByteSpan & nocCertBuf,
                                           const ByteSpan & icaCertBuf);
     /* This function sends the trusted root certificate to the device.
-       The function does not hold a refernce to the device object.
+       The function does not hold a reference to the device object.
      */
     CHIP_ERROR SendTrustedRootCertificate(CommissioneeDeviceProxy * device, const ByteSpan & rcac);
 
     /* This function is called by the commissioner code when the device completes
        the operational credential provisioning process.
-       The function does not hold a refernce to the device object.
+       The function does not hold a reference to the device object.
        */
     CHIP_ERROR OnOperationalCredentialsProvisioningCompletion(CommissioneeDeviceProxy * device);
 
diff --git a/src/controller/InvokeInteraction.h b/src/controller/InvokeInteraction.h
index ab34ed9..817433c 100644
--- a/src/controller/InvokeInteraction.h
+++ b/src/controller/InvokeInteraction.h
@@ -78,8 +78,8 @@
     ReturnErrorOnFailure(commandSender->SendCommandRequest(sessionHandle));
 
     //
-    // We've effectively transfered ownership of the above allocated objects to CommandSender, and we need to wait for it to call us
-    // back when processing is completed (through OnDone) to eventually free up resources.
+    // We've effectively transferred ownership of the above allocated objects to CommandSender, and we need to wait for it to call
+    // us back when processing is completed (through OnDone) to eventually free up resources.
     //
     // So signal that by releasing the smart pointer.
     //
diff --git a/src/controller/python/chip-device-ctrl.py b/src/controller/python/chip-device-ctrl.py
index 54d448c..2949ec1 100755
--- a/src/controller/python/chip-device-ctrl.py
+++ b/src/controller/python/chip-device-ctrl.py
@@ -690,7 +690,7 @@
             group.add_argument(
                 '-s', help='discover commissionable nodes with given short discriminator', type=int)
             group.add_argument(
-                '-v', help='discover commissionable nodes wtih given vendor ID', type=int)
+                '-v', help='discover commissionable nodes with given vendor ID', type=int)
             group.add_argument(
                 '-t', help='discover commissionable nodes with given device type', type=int)
             group.add_argument(
diff --git a/src/controller/python/chip/ChipDeviceCtrl.py b/src/controller/python/chip/ChipDeviceCtrl.py
index 001635a..ec4650c 100644
--- a/src/controller/python/chip/ChipDeviceCtrl.py
+++ b/src/controller/python/chip/ChipDeviceCtrl.py
@@ -58,7 +58,7 @@
 
 
 # This is a fix for WEAV-429. Jay Logue recommends revisiting this at a later
-# date to allow for truely multiple instances so this is temporary.
+# date to allow for truly multiple instances so this is temporary.
 
 
 def _singleton(cls):
diff --git a/src/controller/python/chip/clusters/ClusterObjects.py b/src/controller/python/chip/clusters/ClusterObjects.py
index d1f46ea..7b00bca 100644
--- a/src/controller/python/chip/clusters/ClusterObjects.py
+++ b/src/controller/python/chip/clusters/ClusterObjects.py
@@ -140,7 +140,7 @@
         for tag, value in tlvData.items():
             descriptor = self.GetFieldByTag(tag)
             if not descriptor:
-                # We do not have enough infomation for this field.
+                # We do not have enough information for this field.
                 ret[tag] = value
                 continue
 
diff --git a/src/controller/tests/TestReadChunking.cpp b/src/controller/tests/TestReadChunking.cpp
index da1a327..d14c289 100644
--- a/src/controller/tests/TestReadChunking.cpp
+++ b/src/controller/tests/TestReadChunking.cpp
@@ -176,7 +176,7 @@
 
 /*
  * This validates all the various corner cases encountered during chunking by
- * artifically reducing the size of a packet buffer used to encode attribute data
+ * artificially reducing the size of a packet buffer used to encode attribute data
  * to force chunking to happen over multiple packets even with a small number of attributes
  * and then slowly increasing the available size by 1 byte in each test iteration and re-running
  * the report generation logic. This 1-byte incremental approach sweeps through from a base scenario of
diff --git a/src/credentials/DeviceAttestationConstructor.h b/src/credentials/DeviceAttestationConstructor.h
index 8aaebee..0072b8c 100644
--- a/src/credentials/DeviceAttestationConstructor.h
+++ b/src/credentials/DeviceAttestationConstructor.h
@@ -27,10 +27,10 @@
 constexpr size_t kExpectedAttestationNonceSize = 32;
 
 /**
- *  @brief Take the attestation elements buffer and return each component seperately.
+ *  @brief Take the attestation elements buffer and return each component separately.
  *         All output data stays valid while attestationElements buffer is valid.
  *
- *  @param[in]    attestationElements ByteSpan containg source of Attestation Elements data.
+ *  @param[in]    attestationElements ByteSpan containing source of Attestation Elements data.
  *  @param[out]   certificationDeclaration
  *  @param[out]   attestationNonce
  *  @param[out]   timestamp
diff --git a/src/crypto/CHIPCryptoPAL.h b/src/crypto/CHIPCryptoPAL.h
index 3eaae07..ab6f3bc 100644
--- a/src/crypto/CHIPCryptoPAL.h
+++ b/src/crypto/CHIPCryptoPAL.h
@@ -820,7 +820,7 @@
                                      size_t Lin_len);
 
     /**
-     * @brief Start the Spake2+ process as a prover (i.e. a commisioner).
+     * @brief Start the Spake2+ process as a prover (i.e. a commissioner).
      *
      * @param my_identity       The prover identity. May be NULL if identities are not established.
      * @param my_identity_len   The prover identity length.
diff --git a/src/crypto/CHIPCryptoPALOpenSSL.cpp b/src/crypto/CHIPCryptoPALOpenSSL.cpp
index dbe45f1..b36d546 100644
--- a/src/crypto/CHIPCryptoPALOpenSSL.cpp
+++ b/src/crypto/CHIPCryptoPALOpenSSL.cpp
@@ -170,7 +170,7 @@
     VerifyOrExit(tag != nullptr, error = CHIP_ERROR_INVALID_ARGUMENT);
     VerifyOrExit(_isValidTagLength(tag_length), error = CHIP_ERROR_INVALID_ARGUMENT);
 
-    // TODO: Remove suport for AES-256 since not in 1.0
+    // TODO: Remove support for AES-256 since not in 1.0
     // Determine crypto type by key length
     type = (key_length == kAES_CCM128_Key_Length) ? EVP_aes_128_ccm() : EVP_aes_256_ccm();
 
@@ -279,7 +279,7 @@
     VerifyOrExit(iv != nullptr, error = CHIP_ERROR_INVALID_ARGUMENT);
     VerifyOrExit(iv_length > 0, error = CHIP_ERROR_INVALID_ARGUMENT);
 
-    // TODO: Remove suport for AES-256 since not in 1.0
+    // TODO: Remove support for AES-256 since not in 1.0
     // Determine crypto type by key length
     type = (key_length == kAES_CCM128_Key_Length) ? EVP_aes_128_ccm() : EVP_aes_256_ccm();
 
diff --git a/src/crypto/tests/CHIPCryptoPALTest.cpp b/src/crypto/tests/CHIPCryptoPALTest.cpp
index a378a11..1dc409d 100644
--- a/src/crypto/tests/CHIPCryptoPALTest.cpp
+++ b/src/crypto/tests/CHIPCryptoPALTest.cpp
@@ -615,7 +615,7 @@
         out_der_sig.Calloc(out_der_sig_allocated_size);
         NL_TEST_ASSERT(inSuite, out_der_sig);
 
-        // Test converstion from ASN.1 ER to raw
+        // Test conversion from ASN.1 ER to raw
         MutableByteSpan out_raw_sig_span(out_raw_sig.Get(), out_raw_sig_allocated_size);
 
         CHIP_ERROR status = EcdsaAsn1SignatureToRaw(vector->fe_length_bytes,
diff --git a/src/darwin/CHIPTool/CHIPTool/View Controllers/Bindings/BindingsViewController.m b/src/darwin/CHIPTool/CHIPTool/View Controllers/Bindings/BindingsViewController.m
index 419a644..15c639d 100644
--- a/src/darwin/CHIPTool/CHIPTool/View Controllers/Bindings/BindingsViewController.m
+++ b/src/darwin/CHIPTool/CHIPTool/View Controllers/Bindings/BindingsViewController.m
@@ -148,7 +148,7 @@
                       completionHandler:^(NSError * _Nullable error) {
                           NSString * resultString = (error == nil)
                               ? @"Bind command: success!"
-                              : [NSString stringWithFormat:@"An error occured: 0x%02lx", error.code];
+                              : [NSString stringWithFormat:@"An error occurred: 0x%02lx", error.code];
                           NSLog(resultString, nil);
                       }];
             } else {
@@ -180,7 +180,7 @@
                         completionHandler:^(NSError * _Nullable error) {
                             NSString * resultString = (error == nil)
                                 ? @"Unbind command: success!"
-                                : [NSString stringWithFormat:@"An error occured: 0x%02lx", error.code];
+                                : [NSString stringWithFormat:@"An error occurred: 0x%02lx", error.code];
                             NSLog(resultString, nil);
                         }];
             } else {
diff --git a/src/darwin/CHIPTool/CHIPTool/View Controllers/Echo client/EchoViewController.m b/src/darwin/CHIPTool/CHIPTool/View Controllers/Echo client/EchoViewController.m
index 7a4606f..a77321a 100644
--- a/src/darwin/CHIPTool/CHIPTool/View Controllers/Echo client/EchoViewController.m
+++ b/src/darwin/CHIPTool/CHIPTool/View Controllers/Echo client/EchoViewController.m
@@ -117,8 +117,9 @@
                 [self updateResult:@"MfgSpecificPing command sent..."];
 
                 [cluster mfgSpecificPingWithCompletionHandler:^(NSError * _Nullable error) {
-                    NSString * resultString = (error == nil) ? @"MfgSpecificPing command: success!"
-                                                             : [NSString stringWithFormat:@"An error occured: 0x%02lx", error.code];
+                    NSString * resultString = (error == nil)
+                        ? @"MfgSpecificPing command: success!"
+                        : [NSString stringWithFormat:@"An error occurred: 0x%02lx", error.code];
                     [self updateResult:resultString];
                 }];
             } else {
diff --git a/src/darwin/CHIPTool/CHIPTool/View Controllers/OnOffCluster/OnOffViewController.m b/src/darwin/CHIPTool/CHIPTool/View Controllers/OnOffCluster/OnOffViewController.m
index 215fe9c..3801e63 100644
--- a/src/darwin/CHIPTool/CHIPTool/View Controllers/OnOffCluster/OnOffViewController.m
+++ b/src/darwin/CHIPTool/CHIPTool/View Controllers/OnOffCluster/OnOffViewController.m
@@ -244,7 +244,7 @@
                                                                     queue:dispatch_get_main_queue()];
                     [onOff onWithCompletionHandler:^(NSError * error) {
                         NSString * resultString = (error != nil)
-                            ? [NSString stringWithFormat:@"An error occured: 0x%02lx", error.code]
+                            ? [NSString stringWithFormat:@"An error occurred: 0x%02lx", error.code]
                             : @"On command success";
                         [self updateResult:resultString];
                     }];
@@ -273,7 +273,7 @@
                                                                     queue:dispatch_get_main_queue()];
                     [onOff offWithCompletionHandler:^(NSError * error) {
                         NSString * resultString = (error != nil)
-                            ? [NSString stringWithFormat:@"An error occured: 0x%02lx", error.code]
+                            ? [NSString stringWithFormat:@"An error occurred: 0x%02lx", error.code]
                             : @"Off command success";
                         [self updateResult:resultString];
                     }];
@@ -302,7 +302,7 @@
                                                                     queue:dispatch_get_main_queue()];
                     [onOff toggleWithCompletionHandler:^(NSError * error) {
                         NSString * resultString = (error != nil)
-                            ? [NSString stringWithFormat:@"An error occured: 0x%02lx", error.code]
+                            ? [NSString stringWithFormat:@"An error occurred: 0x%02lx", error.code]
                             : @"Toggle command success";
                         [self updateResult:resultString];
                     }];
diff --git a/src/darwin/Framework/CHIPTests/CHIPClustersTests.m b/src/darwin/Framework/CHIPTests/CHIPClustersTests.m
index 2a0b624..3e804f2 100644
--- a/src/darwin/Framework/CHIPTests/CHIPClustersTests.m
+++ b/src/darwin/Framework/CHIPTests/CHIPClustersTests.m
@@ -7128,7 +7128,7 @@
 }
 - (void)testSendClusterTest_TC_CC_8_1_000003_ColorLoopSet
 {
-    XCTestExpectation * expectation = [self expectationWithDescription:@"Color Loop Set Command - Set all Attributs"];
+    XCTestExpectation * expectation = [self expectationWithDescription:@"Color Loop Set Command - Set all Attributes"];
 
     CHIPDevice * device = GetConnectedDevice();
     dispatch_queue_t queue = dispatch_get_main_queue();
@@ -7145,7 +7145,7 @@
     params.optionsOverride = [NSNumber numberWithUnsignedChar:0];
     [cluster colorLoopSetWithParams:params
                   completionHandler:^(NSError * _Nullable err) {
-                      NSLog(@"Color Loop Set Command - Set all Attributs Error: %@", err);
+                      NSLog(@"Color Loop Set Command - Set all Attributes Error: %@", err);
 
                       XCTAssertEqual([CHIPErrorTestUtils errorToZCLErrorCode:err], 0);
 
diff --git a/src/include/platform/NFCManager.h b/src/include/platform/NFCManager.h
index 7513c19..6028f86 100644
--- a/src/include/platform/NFCManager.h
+++ b/src/include/platform/NFCManager.h
@@ -35,7 +35,7 @@
  * @brief Defines an abstract interface for programming an NFC Tag.
  *
  * NFC Tag can be used in Project CHIP to share commissioning information such
- * as the device discriminator and PIN code with a comissioner. This class
+ * as the device discriminator and PIN code with a commissioner. This class
  * provides an interface to set contents of a programmable NFC Tag.
  */
 class NFCManager
diff --git a/src/inet/TCPEndPointImplSockets.cpp b/src/inet/TCPEndPointImplSockets.cpp
index faa6972..199628c 100644
--- a/src/inet/TCPEndPointImplSockets.cpp
+++ b/src/inet/TCPEndPointImplSockets.cpp
@@ -80,12 +80,12 @@
         // Enable SO_REUSEPORT.  This permits coexistence between an
         // untargetted CHIP client and other services that listen on
         // a CHIP port on a specific address (such as a CHIP client
-        // with TARGETTED_LISTEN or TCP proxying services).  Note that
+        // with TARGETED_LISTEN or TCP proxying services).  Note that
         // one of the costs of this implementation is the
         // non-deterministic connection dispatch when multple clients
-        // listen on the address wih the same degreee of selectivity,
+        // listen on the address with the same degreee of selectivity,
         // e.g. two untargetted-listen CHIP clients, or two
-        // targetted-listen CHIP clients with the same node id.
+        // targeted-listen CHIP clients with the same node id.
 
         if (setsockopt(mSocket, SOL_SOCKET, SO_REUSEPORT, &n, sizeof(n)) != 0)
         {
diff --git a/src/lib/core/CHIPCallback.h b/src/lib/core/CHIPCallback.h
index 69d2648..dd010ea 100644
--- a/src/lib/core/CHIPCallback.h
+++ b/src/lib/core/CHIPCallback.h
@@ -118,7 +118,7 @@
     void * mContext;
 
     /**
-     * where to call when the event of interest has occured
+     * where to call when the event of interest has occurred
      */
     T mCall;
 
diff --git a/src/lib/core/CHIPConfig.h b/src/lib/core/CHIPConfig.h
index 3905ca1..40d7f48 100644
--- a/src/lib/core/CHIPConfig.h
+++ b/src/lib/core/CHIPConfig.h
@@ -1330,7 +1330,7 @@
  *          1 -- Message Type
  *          2 -- Exchange Id
  *          4 -- Profile Id
- *          4 -- Acknowleged Message Id
+ *          4 -- Acknowledged Message Id
  *
  *    @note A number of these fields are optional or not presently used.
  *          So most headers will be considerably smaller than this.
diff --git a/src/lib/core/CHIPEncoding.h b/src/lib/core/CHIPEncoding.h
index dd4f67d..6419e7e 100644
--- a/src/lib/core/CHIPEncoding.h
+++ b/src/lib/core/CHIPEncoding.h
@@ -192,7 +192,7 @@
  *  </ul>
  *
  *  On little endian host systems no actual byte reordering will
- *  occur. On other systems, byte reordering is peformed as
+ *  occur. On other systems, byte reordering is performed as
  *  appropriate.
  *
  */
@@ -562,7 +562,7 @@
  *  </ul>
  *
  *  On big endian host systems no actual byte reordering will
- *  occur. On other systems, byte reordering is peformed as
+ *  occur. On other systems, byte reordering is performed as
  *  appropriate.
  *
  */
diff --git a/src/lib/core/CHIPError.cpp b/src/lib/core/CHIPError.cpp
index cfe76b2..285cdb3 100644
--- a/src/lib/core/CHIPError.cpp
+++ b/src/lib/core/CHIPError.cpp
@@ -593,8 +593,8 @@
     case CHIP_ERROR_UNSUPPORTED_WIRELESS_OPERATING_LOCATION.AsInteger():
         desc = "Unsupported wireless operating location";
         break;
-    case CHIP_ERROR_MDNS_COLLISSION.AsInteger():
-        desc = "mDNS collission";
+    case CHIP_ERROR_MDNS_COLLISION.AsInteger():
+        desc = "mDNS collision";
         break;
     case CHIP_ERROR_IM_MALFORMED_ATTRIBUTE_PATH.AsInteger():
         desc = "Malformed Interacton Model Attribute Path";
diff --git a/src/lib/core/CHIPError.h b/src/lib/core/CHIPError.h
index 99f5010..f103999 100644
--- a/src/lib/core/CHIPError.h
+++ b/src/lib/core/CHIPError.h
@@ -1512,7 +1512,7 @@
  *  @def CHIP_ERROR_INVALID_TAKE_PARAMETER
  *
  *  @brief
- *    Received an invalid TAKE paramter.
+ *    Received an invalid TAKE parameter.
  *
  */
 #define CHIP_ERROR_INVALID_TAKE_PARAMETER                      CHIP_CORE_ERROR(0x7c)
@@ -2011,13 +2011,13 @@
 #define CHIP_ERROR_UNSUPPORTED_WIRELESS_OPERATING_LOCATION     CHIP_CORE_ERROR(0xb3)
 
 /**
- *  @def CHIP_ERROR_MDNS_COLLISSION
+ *  @def CHIP_ERROR_MDNS_COLLISION
  *
  *  @brief
  *    The registered service name has collision on the LAN.
  *
  */
-#define CHIP_ERROR_MDNS_COLLISSION                             CHIP_CORE_ERROR(0xb4)
+#define CHIP_ERROR_MDNS_COLLISION                             CHIP_CORE_ERROR(0xb4)
 
 /**
  * @def CHIP_ERROR_IM_MALFORMED_ATTRIBUTE_PATH
diff --git a/src/lib/core/CHIPTLV.h b/src/lib/core/CHIPTLV.h
index f9907d3..f85d0dc 100644
--- a/src/lib/core/CHIPTLV.h
+++ b/src/lib/core/CHIPTLV.h
@@ -1450,7 +1450,7 @@
     CHIP_ERROR Put(Tag tag, bool v)
     {
         /*
-         * In TLV, boolean values are encoded as standalone tags without actual values, so we have a seperate
+         * In TLV, boolean values are encoded as standalone tags without actual values, so we have a separate
          * PutBoolean method.
          */
         return PutBoolean(tag, v);
diff --git a/src/lib/dnssd/Advertiser_ImplNone.cpp b/src/lib/dnssd/Advertiser_ImplNone.cpp
index 503366a..a3cc54a 100644
--- a/src/lib/dnssd/Advertiser_ImplNone.cpp
+++ b/src/lib/dnssd/Advertiser_ImplNone.cpp
@@ -48,7 +48,7 @@
 
     CHIP_ERROR Advertise(const CommissionAdvertisingParameters & params) override
     {
-        ChipLogError(Discovery, "DNS-SD advertising not available. Commisioning Advertisement failed.");
+        ChipLogError(Discovery, "DNS-SD advertising not available. Commissioning Advertisement failed.");
         return CHIP_ERROR_NOT_IMPLEMENTED;
     }
 
diff --git a/src/lib/dnssd/Resolver_ImplMinimalMdns.cpp b/src/lib/dnssd/Resolver_ImplMinimalMdns.cpp
index 3def051..75fcc27 100644
--- a/src/lib/dnssd/Resolver_ImplMinimalMdns.cpp
+++ b/src/lib/dnssd/Resolver_ImplMinimalMdns.cpp
@@ -599,7 +599,7 @@
 }
 
 // Minimal implementation does not support associating a context to a request (while platforms implementations do). So keep
-// updating the delegate that ends up beeing used by the server by calling 'SetResolverDelegate'.
+// updating the delegate that ends up being used by the server by calling 'SetResolverDelegate'.
 // This effectively allow minimal to have multiple controllers issuing requests as long the requests are serialized, but
 // it won't work well if requests are issued in parallel.
 CHIP_ERROR ResolverProxy::ResolveNodeId(const PeerId & peerId, Inet::IPAddressType type, Resolver::CacheBypass dnssdCacheBypass)
diff --git a/src/lib/dnssd/TxtFields.h b/src/lib/dnssd/TxtFields.h
index 36de54e..14d4e41 100644
--- a/src/lib/dnssd/TxtFields.h
+++ b/src/lib/dnssd/TxtFields.h
@@ -123,7 +123,7 @@
             max = sizeof(info.keyStr) > max ? sizeof(info.keyStr) : max;
         }
     }
-    // minus 1 becuase sizeof includes the null terminator.
+    // minus 1 because sizeof includes the null terminator.
     return max - 1;
 }
 constexpr size_t TotalKeyLen(TxtKeyUse use)
@@ -149,7 +149,7 @@
             max = info.valMaxSize > max ? info.valMaxSize : max;
         }
     }
-    // minus 1 becuase sizeof includes the null terminator.
+    // minus 1 because sizeof includes the null terminator.
     return max - 1;
 }
 constexpr size_t TotalValueLen(TxtKeyUse use)
diff --git a/src/lib/dnssd/minimal_mdns/Parser.h b/src/lib/dnssd/minimal_mdns/Parser.h
index 1b2b208..8150f07 100644
--- a/src/lib/dnssd/minimal_mdns/Parser.h
+++ b/src/lib/dnssd/minimal_mdns/Parser.h
@@ -116,7 +116,7 @@
 ///
 /// Calls appropriate delegate callbacks while parsing
 ///
-/// returns true if packet was succesfully parsed, false otherwise
+/// returns true if packet was successfully parsed, false otherwise
 bool ParsePacket(const BytesRange & packetData, ParserDelegate * delegate);
 
 } // namespace Minimal
diff --git a/src/lib/dnssd/minimal_mdns/ResponseSender.cpp b/src/lib/dnssd/minimal_mdns/ResponseSender.cpp
index 2a7378e..0209ff8 100644
--- a/src/lib/dnssd/minimal_mdns/ResponseSender.cpp
+++ b/src/lib/dnssd/minimal_mdns/ResponseSender.cpp
@@ -228,7 +228,7 @@
         mResponseBuilder.AddRecord(mSendState.GetResourceType(), record);
         if (!mResponseBuilder.Ok())
         {
-            // Very much unexpected: single record addtion should fit (our records should not be that big).
+            // Very much unexpected: single record addition should fit (our records should not be that big).
             ChipLogError(Discovery, "Failed to add single record to mDNS response.");
             mSendState.SetError(CHIP_ERROR_INTERNAL);
         }
diff --git a/src/lib/dnssd/minimal_mdns/responders/QueryResponder.cpp b/src/lib/dnssd/minimal_mdns/responders/QueryResponder.cpp
index 904e664..5f14659 100644
--- a/src/lib/dnssd/minimal_mdns/responders/QueryResponder.cpp
+++ b/src/lib/dnssd/minimal_mdns/responders/QueryResponder.cpp
@@ -45,7 +45,7 @@
 
     if (mResponderInfoSize < 2)
     {
-        // Nothing usefull really
+        // Nothing useful really
         ChipLogError(Discovery, "Query responder storage size too small");
     }
 }
diff --git a/src/lib/dnssd/minimal_mdns/tests/TestResponseSender.cpp b/src/lib/dnssd/minimal_mdns/tests/TestResponseSender.cpp
index 0eb40ad..2fdab46 100644
--- a/src/lib/dnssd/minimal_mdns/tests/TestResponseSender.cpp
+++ b/src/lib/dnssd/minimal_mdns/tests/TestResponseSender.cpp
@@ -140,7 +140,7 @@
 
     QueryData queryData = QueryData(QType::ANY, QClass::IN, false, common.requestNameStart, common.requestBytesRange);
 
-    // We should get all because we request to report all instance names when teh PTR is sent.
+    // We should get all because we request to report all instance names when the PTR is sent.
     common.server.AddExpectedRecord(&common.ptrRecord);
     common.server.AddExpectedRecord(&common.srvRecord);
     common.server.AddExpectedRecord(&common.txtRecord);
diff --git a/src/lib/dnssd/tests/TestServiceNaming.cpp b/src/lib/dnssd/tests/TestServiceNaming.cpp
index adc48bd..bbf1989 100644
--- a/src/lib/dnssd/tests/TestServiceNaming.cpp
+++ b/src/lib/dnssd/tests/TestServiceNaming.cpp
@@ -147,7 +147,7 @@
     NL_TEST_ASSERT(inSuite, strcmp(buffer, "_T3") == 0);
     // TODO: Add tests for longer device types once spec issue #3226 is closed.
 
-    // Commisioning mode tests
+    // Commissioning mode tests
     filter.type = DiscoveryFilterType::kCommissioningMode;
     NL_TEST_ASSERT(inSuite, MakeServiceSubtype(buffer, sizeof(buffer), filter) == CHIP_NO_ERROR);
     NL_TEST_ASSERT(inSuite, strcmp(buffer, "_CM") == 0);
@@ -232,7 +232,7 @@
                    MakeServiceTypeName(buffer, sizeof(buffer), filter, DiscoveryType::kCommissionableNode) == CHIP_NO_ERROR);
     NL_TEST_ASSERT(inSuite, strcmp(buffer, "_T3._sub._matterc") == 0);
 
-    // Commisioning mode tests
+    // Commissioning mode tests
     filter.type = DiscoveryFilterType::kCommissioningMode;
     NL_TEST_ASSERT(inSuite,
                    MakeServiceTypeName(buffer, sizeof(buffer), filter, DiscoveryType::kCommissionableNode) == CHIP_NO_ERROR);
diff --git a/src/lib/support/PersistentStorageMacros.h b/src/lib/support/PersistentStorageMacros.h
index 4c9be7e..1e3af53 100644
--- a/src/lib/support/PersistentStorageMacros.h
+++ b/src/lib/support/PersistentStorageMacros.h
@@ -38,7 +38,7 @@
     {                                                                                                                              \
         constexpr size_t len = std::extent<decltype(keyPrefix)>::value;                                                            \
         nlSTATIC_ASSERT_PRINT(len > 0, "keyPrefix length must be known at compile time");                                          \
-        /* 2 * sizeof(chip::NodeId) to accomodate 2 character for each byte in Node Id */                                          \
+        /* 2 * sizeof(chip::NodeId) to accommodate 2 character for each byte in Node Id */                                         \
         char key[len + 2 * sizeof(chip::NodeId) + 1];                                                                              \
         nlSTATIC_ASSERT_PRINT(sizeof(node) <= sizeof(uint64_t), "Node ID size is greater than expected");                          \
         snprintf(key, sizeof(key), "%s%" PRIx64, keyPrefix, node);                                                                 \
diff --git a/src/lib/support/StateMachine.h b/src/lib/support/StateMachine.h
index 329dd27..b9b5152 100644
--- a/src/lib/support/StateMachine.h
+++ b/src/lib/support/StateMachine.h
@@ -221,7 +221,7 @@
             mCurrentState.LogTransition(oldState.GetName());
             // It is impermissible to dispatch events from Exit() or
             // LogTransition(), or from the transitions table when a transition
-            // has also been returned.  Verify that this hasn't occured.
+            // has also been returned.  Verify that this hasn't occurred.
             VerifyOrDie(prev == mSequence);
             mCurrentState.Enter();
         }
diff --git a/src/lib/support/tests/TestFixedBufferAllocator.cpp b/src/lib/support/tests/TestFixedBufferAllocator.cpp
index 3c8ebf4..8bd42fc 100644
--- a/src/lib/support/tests/TestFixedBufferAllocator.cpp
+++ b/src/lib/support/tests/TestFixedBufferAllocator.cpp
@@ -62,7 +62,7 @@
     NL_TEST_ASSERT(inSuite, alloc.AnyAllocFailed());
 }
 
-const nlTest sTests[] = { NL_TEST_DEF("Test successfull clone", TestClone), NL_TEST_DEF("Test out of memory", TestOutOfMemory),
+const nlTest sTests[] = { NL_TEST_DEF("Test successful clone", TestClone), NL_TEST_DEF("Test out of memory", TestOutOfMemory),
                           NL_TEST_SENTINEL() };
 
 } // namespace
diff --git a/src/lib/support/tests/TestPrivateHeap.cpp b/src/lib/support/tests/TestPrivateHeap.cpp
index 54e3309..85bdd91 100644
--- a/src/lib/support/tests/TestPrivateHeap.cpp
+++ b/src/lib/support/tests/TestPrivateHeap.cpp
@@ -313,7 +313,7 @@
     FillKnownPattern(p1, 16, 33);
     p2 = allocator.HeapRealloc(p1, 32); // resize, does not fit. This frees p1
     NL_TEST_ASSERT(inSuite, p2 != nullptr);
-    NL_TEST_ASSERT(inSuite, p2 != p1); // new reallocation occured
+    NL_TEST_ASSERT(inSuite, p2 != p1); // new reallocation occurred
     NL_TEST_ASSERT(inSuite, IsKnownPattern(p2, 16, 33));
 
     void * p3 = allocator.HeapAlloc(48); // insufficient heap for this
diff --git a/src/lwip/standalone/lwipopts.h b/src/lwip/standalone/lwipopts.h
index c3243ad..84aa44e 100644
--- a/src/lwip/standalone/lwipopts.h
+++ b/src/lwip/standalone/lwipopts.h
@@ -87,7 +87,7 @@
 /**
  * PBUF_POOL_SIZE: the number of buffers in the pbuf pool.
  *
- * This is just a default designed to be overriden by the FreeRTOS.mk makefile
+ * This is just a default designed to be overridden by the FreeRTOS.mk makefile
  * To perform this override, define the makefile variable LWIP_NUM_PACKET_BUFFERS_IN_POOL
  */
 #ifndef PBUF_POOL_SIZE
@@ -135,7 +135,7 @@
 
 /**
  * PBUF_POOL_BUFSIZE: the size of each pbuf in the pbuf pool. The default is
- * designed to accomodate single full size link-layer frame in one pbuf, including
+ * designed to accommodate single full size link-layer frame in one pbuf, including
  * the link-layer header and any link-layer encapsulation header, and the pbuf
  * structure itself.
  */
@@ -151,7 +151,7 @@
 
 /**
  * ETH_PAD_SIZE: the header space required preceeding the of each pbuf in the pbuf pool. The default is
- * designed to accomodate single full size TCP frame in one pbuf, including
+ * designed to accommodate single full size TCP frame in one pbuf, including
  * TCP_MSS, IP header, and link header.
  *
  * This is zero since the role has been taken over by SUB_ETHERNET_HEADER_SPACE as ETH_PAD_SIZE was not always obeyed
@@ -356,7 +356,7 @@
 #endif
 
 /**
- * LWIP_IPV6_ROUTE_TABLE_SUPPORT==1: Enable support for a routing table and refering these during forwarding.
+ * LWIP_IPV6_ROUTE_TABLE_SUPPORT==1: Enable support for a routing table and referring these during forwarding.
  */
 #ifndef LWIP_IPV6_ROUTE_TABLE_SUPPORT
 #define LWIP_IPV6_ROUTE_TABLE_SUPPORT 1
diff --git a/src/messaging/tests/MessagingContext.cpp b/src/messaging/tests/MessagingContext.cpp
index 82b5b49..267cc93 100644
--- a/src/messaging/tests/MessagingContext.cpp
+++ b/src/messaging/tests/MessagingContext.cpp
@@ -100,13 +100,13 @@
 
 Messaging::ExchangeContext * MessagingContext::NewExchangeToAlice(Messaging::ExchangeDelegate * delegate)
 {
-    // TODO: temprary create a SessionHandle from node id, will be fix in PR 3602
+    // TODO: temporary create a SessionHandle from node id, will be fix in PR 3602
     return mExchangeManager.NewContext(GetSessionBobToAlice(), delegate);
 }
 
 Messaging::ExchangeContext * MessagingContext::NewExchangeToBob(Messaging::ExchangeDelegate * delegate)
 {
-    // TODO: temprary create a SessionHandle from node id, will be fix in PR 3602
+    // TODO: temporary create a SessionHandle from node id, will be fix in PR 3602
     return mExchangeManager.NewContext(GetSessionAliceToBob(), delegate);
 }
 
diff --git a/src/platform/EFR32/KeyValueStoreManagerImpl.h b/src/platform/EFR32/KeyValueStoreManagerImpl.h
index bd504a3..32650db 100644
--- a/src/platform/EFR32/KeyValueStoreManagerImpl.h
+++ b/src/platform/EFR32/KeyValueStoreManagerImpl.h
@@ -67,7 +67,7 @@
 
     /**
      * @brief
-     * Erases all data in the KVS partition, KVS needs to be initalized after
+     * Erases all data in the KVS partition, KVS needs to be initialized after
      * this operation.
      *
      * @return CHIP_NO_ERROR the partiton was erased.
diff --git a/src/platform/Linux/DnssdImpl.cpp b/src/platform/Linux/DnssdImpl.cpp
index cfc0415..7709a8e 100644
--- a/src/platform/Linux/DnssdImpl.cpp
+++ b/src/platform/Linux/DnssdImpl.cpp
@@ -439,8 +439,8 @@
         ChipLogProgress(DeviceLayer, "Avahi group established");
         break;
     case AVAHI_ENTRY_GROUP_COLLISION:
-        ChipLogError(DeviceLayer, "Avahi group collission");
-        mErrorCallback(mAsyncReturnContext, CHIP_ERROR_MDNS_COLLISSION);
+        ChipLogError(DeviceLayer, "Avahi group collision");
+        mErrorCallback(mAsyncReturnContext, CHIP_ERROR_MDNS_COLLISION);
         break;
     case AVAHI_ENTRY_GROUP_FAILURE:
         ChipLogError(DeviceLayer, "Avahi group internal failure %s",
diff --git a/src/platform/P6/BLEManagerImpl.cpp b/src/platform/P6/BLEManagerImpl.cpp
index 69620b2..b121185 100644
--- a/src/platform/P6/BLEManagerImpl.cpp
+++ b/src/platform/P6/BLEManagerImpl.cpp
@@ -819,7 +819,7 @@
         localDeviceNameLen = strlen(sInstance.mDeviceName);
     }
 
-    /* First element is the advertisment flags */
+    /* First element is the advertisement flags */
     adv_elem[num_elem].advert_type = BTM_BLE_ADVERT_TYPE_FLAG;
     adv_elem[num_elem].len         = sizeof(uint8_t);
     adv_elem[num_elem].p_data      = &flag;
diff --git a/src/platform/Zephyr/BLEManagerImpl.cpp b/src/platform/Zephyr/BLEManagerImpl.cpp
index 8b7696d..5233148 100644
--- a/src/platform/Zephyr/BLEManagerImpl.cpp
+++ b/src/platform/Zephyr/BLEManagerImpl.cpp
@@ -221,7 +221,7 @@
     const uint8_t advFlags        = BT_LE_AD_GENERAL | BT_LE_AD_NO_BREDR;
     const bool isAdvertisingRerun = mFlags.Has(Flags::kAdvertising);
 
-    // At first run always select fast advertising, on the next attemp slow down interval.
+    // At first run always select fast advertising, on the next attempt slow down interval.
     const uint32_t intervalMin = mFlags.Has(Flags::kFastAdvertisingEnabled) ? CHIP_DEVICE_CONFIG_BLE_FAST_ADVERTISING_INTERVAL_MIN
                                                                             : CHIP_DEVICE_CONFIG_BLE_SLOW_ADVERTISING_INTERVAL_MIN;
     const uint32_t intervalMax = mFlags.Has(Flags::kFastAdvertisingEnabled) ? CHIP_DEVICE_CONFIG_BLE_FAST_ADVERTISING_INTERVAL_MAX
diff --git a/src/platform/cc13x2_26x2/BLEManagerImpl.cpp b/src/platform/cc13x2_26x2/BLEManagerImpl.cpp
index 218855f..8072f5a 100644
--- a/src/platform/cc13x2_26x2/BLEManagerImpl.cpp
+++ b/src/platform/cc13x2_26x2/BLEManagerImpl.cpp
@@ -748,7 +748,7 @@
                 }
                 else
                 {
-                    /* PHY Update successfull */
+                    /* PHY Update successful */
                 }
             }
             break;
diff --git a/src/platform/cc13x2_26x2/Logging.cpp b/src/platform/cc13x2_26x2/Logging.cpp
index 7cfe2d7..6d0e932 100644
--- a/src/platform/cc13x2_26x2/Logging.cpp
+++ b/src/platform/cc13x2_26x2/Logging.cpp
@@ -56,7 +56,7 @@
 /**
  * Called whenever a log message is emitted.
  *
- * Can be overriden by the device logging file
+ * Can be overridden by the device logging file
  */
 void __attribute__((weak)) OnLogOutput(void) {}
 
diff --git a/src/platform/device.gni b/src/platform/device.gni
index 7fac986..ff9ce0b 100755
--- a/src/platform/device.gni
+++ b/src/platform/device.gni
@@ -21,7 +21,7 @@
   chip_device_platform = "auto"
   chip_platform_target = ""
 
-  # Substitue fake platform when building with chip_device_platform=auto.
+  # Substitute fake platform when building with chip_device_platform=auto.
   chip_fake_platform = false
 }
 
diff --git a/src/platform/mbed/Logging.cpp b/src/platform/mbed/Logging.cpp
index 42e6b9f..0da70e4 100644
--- a/src/platform/mbed/Logging.cpp
+++ b/src/platform/mbed/Logging.cpp
@@ -93,7 +93,7 @@
 
 void mbed_logging_init()
 {
-    // Mbed trace initalization
+    // Mbed trace initialization
     mbed_trace_init();
     mbed_trace_include_filters_set((char *) TRACE_GROUP);
     mbed_trace_config_set(TRACE_ACTIVE_LEVEL_ALL | TRACE_MODE_COLOR);
diff --git a/src/protocols/bdx/BdxMessages.h b/src/protocols/bdx/BdxMessages.h
index 9ac493d..0fd13d7 100644
--- a/src/protocols/bdx/BdxMessages.h
+++ b/src/protocols/bdx/BdxMessages.h
@@ -95,7 +95,7 @@
      *  so it is essential that the underlying PacketBuffer is not modified until after this
      *  struct is no longer needed.
      *
-     * @param[in] aBuffer A PacketBufferHandle with a refernce to the PacketBuffer containing the data.
+     * @param[in] aBuffer A PacketBufferHandle with a reference to the PacketBuffer containing the data.
      *
      * @return CHIP_ERROR Return an error if the message format is invalid and/or can't be parsed
      */
diff --git a/src/protocols/bdx/BdxTransferSession.cpp b/src/protocols/bdx/BdxTransferSession.cpp
index 33665bb..f92fb10 100644
--- a/src/protocols/bdx/BdxTransferSession.cpp
+++ b/src/protocols/bdx/BdxTransferSession.cpp
@@ -123,7 +123,7 @@
         break;
     }
 
-    // If there's no other pending output but an error occured or was received, then continue to output the error.
+    // If there's no other pending output but an error occurred or was received, then continue to output the error.
     // This ensures that when the TransferSession encounters an error and needs to send a StatusReport, both a kMsgToSend and a
     // kInternalError output event will be emitted.
     if (event.EventType == OutputEventType::kNone && mState == TransferState::kErrorState)
diff --git a/src/protocols/echo/Echo.h b/src/protocols/echo/Echo.h
index 06eefea..1f3429b 100644
--- a/src/protocols/echo/Echo.h
+++ b/src/protocols/echo/Echo.h
@@ -18,7 +18,7 @@
 
 /**
  *    @file
- *      This file defines objects for a CHIP Echo unsolicitied
+ *      This file defines objects for a CHIP Echo unsolicited
  *      initaitor (client) and responder (server).
  *
  */
diff --git a/src/protocols/echo/EchoClient.cpp b/src/protocols/echo/EchoClient.cpp
index 1ac1662..e8bf65c 100644
--- a/src/protocols/echo/EchoClient.cpp
+++ b/src/protocols/echo/EchoClient.cpp
@@ -18,7 +18,7 @@
 
 /**
  *    @file
- *      This file implements an object for a CHIP Echo unsolicitied
+ *      This file implements an object for a CHIP Echo unsolicited
  *      initiator (client).
  *
  */
diff --git a/src/protocols/echo/EchoServer.cpp b/src/protocols/echo/EchoServer.cpp
index f93b879..a9fea3e 100644
--- a/src/protocols/echo/EchoServer.cpp
+++ b/src/protocols/echo/EchoServer.cpp
@@ -18,7 +18,7 @@
 
 /**
  *    @file
- *      This file implements an object for a CHIP Echo unsolicitied
+ *      This file implements an object for a CHIP Echo unsolicited
  *      responder (server).
  *
  */
diff --git a/src/protocols/secure_channel/CASESession.cpp b/src/protocols/secure_channel/CASESession.cpp
index 5026813..015e61e 100644
--- a/src/protocols/secure_channel/CASESession.cpp
+++ b/src/protocols/secure_channel/CASESession.cpp
@@ -214,7 +214,7 @@
 {
     CHIP_ERROR err = CHIP_NO_ERROR;
 
-    // Return early on error here, as we have not initalized any state yet
+    // Return early on error here, as we have not initialized any state yet
     ReturnErrorCodeIf(exchangeCtxt == nullptr, CHIP_ERROR_INVALID_ARGUMENT);
     ReturnErrorCodeIf(fabric == nullptr, CHIP_ERROR_INVALID_ARGUMENT);
 
diff --git a/src/protocols/secure_channel/PASESession.cpp b/src/protocols/secure_channel/PASESession.cpp
index ba62a8a..aadda0f 100644
--- a/src/protocols/secure_channel/PASESession.cpp
+++ b/src/protocols/secure_channel/PASESession.cpp
@@ -254,7 +254,7 @@
                                        uint16_t mySessionId, Optional<ReliableMessageProtocolConfig> mrpConfig,
                                        SessionEstablishmentDelegate * delegate)
 {
-    // Return early on error here, as we have not initalized any state yet
+    // Return early on error here, as we have not initialized any state yet
     ReturnErrorCodeIf(salt.empty(), CHIP_ERROR_INVALID_ARGUMENT);
     ReturnErrorCodeIf(salt.data() == nullptr, CHIP_ERROR_INVALID_ARGUMENT);
 
diff --git a/src/protocols/secure_channel/PASESession.h b/src/protocols/secure_channel/PASESession.h
index 7cd218c..48226c8 100644
--- a/src/protocols/secure_channel/PASESession.h
+++ b/src/protocols/secure_channel/PASESession.h
@@ -165,7 +165,7 @@
      *   Derive a secure session from the paired session. The API will return error
      *   if called before pairing is established.
      *
-     * @param session     Referene to the secure session that will be
+     * @param session     Reference to the secure session that will be
      *                    initialized once pairing is complete
      * @param role        Role of the new session (initiator or responder)
      * @return CHIP_ERROR The result of session derivation
diff --git a/src/protocols/user_directed_commissioning/UserDirectedCommissioning.h b/src/protocols/user_directed_commissioning/UserDirectedCommissioning.h
index c4a9874..0735248 100644
--- a/src/protocols/user_directed_commissioning/UserDirectedCommissioning.h
+++ b/src/protocols/user_directed_commissioning/UserDirectedCommissioning.h
@@ -18,7 +18,7 @@
 
 /**
  *    @file
- *      This file defines objects for a User-Directed Commissioning unsolicitied
+ *      This file defines objects for a User-Directed Commissioning unsolicited
  *      initiator (client) and recipient (server).
  *
  */
diff --git a/src/protocols/user_directed_commissioning/UserDirectedCommissioningClient.cpp b/src/protocols/user_directed_commissioning/UserDirectedCommissioningClient.cpp
index 775de9c..06e1ca1 100644
--- a/src/protocols/user_directed_commissioning/UserDirectedCommissioningClient.cpp
+++ b/src/protocols/user_directed_commissioning/UserDirectedCommissioningClient.cpp
@@ -18,7 +18,7 @@
 
 /**
  *    @file
- *      This file implements an object for a Matter User Directed Commissioning unsolicitied
+ *      This file implements an object for a Matter User Directed Commissioning unsolicited
  *      initiator (client).
  *
  */
diff --git a/src/protocols/user_directed_commissioning/UserDirectedCommissioningServer.cpp b/src/protocols/user_directed_commissioning/UserDirectedCommissioningServer.cpp
index c7608b6..fc73925 100644
--- a/src/protocols/user_directed_commissioning/UserDirectedCommissioningServer.cpp
+++ b/src/protocols/user_directed_commissioning/UserDirectedCommissioningServer.cpp
@@ -18,7 +18,7 @@
 
 /**
  *    @file
- *      This file implements an object for a Matter User Directed Commissioning unsolicitied
+ *      This file implements an object for a Matter User Directed Commissioning unsolicited
  *      recipient (server).
  *
  */
diff --git a/src/system/SystemConfig.h b/src/system/SystemConfig.h
index 7e8450a..fc5ccac 100644
--- a/src/system/SystemConfig.h
+++ b/src/system/SystemConfig.h
@@ -300,7 +300,7 @@
  *          1 -- Message Type
  *          2 -- Exchange Id
  *          4 -- Profile Id
- *          4 -- Acknowleged Message Id
+ *          4 -- Acknowledged Message Id
  *
  *    @note A number of these fields are optional or not presently used. So most headers will be considerably smaller than this.
  */
@@ -331,8 +331,8 @@
  *      Only socket platforms can override the default value. On LwIP-based platforms, the size is derived from the PBUF size
  *      and overriding the value will result in a compile-time error.
  *
- *      This value should be set large enough to accomodate the usage of PacketBuffer in the system. In particular, for the use
- *      in CHIP, the value should be set to accomodate the desired path MTU (i.e. the largest IP packet that can be sent over
+ *      This value should be set large enough to accommodate the usage of PacketBuffer in the system. In particular, for the use
+ *      in CHIP, the value should be set to accommodate the desired path MTU (i.e. the largest IP packet that can be sent over
  *      the network interface) plus any protocol overhead.
  *
  *      For example, sending an IP packet over the tunnel requires additional overheads that depend on platform's network
diff --git a/src/system/SystemPacketBuffer.h b/src/system/SystemPacketBuffer.h
index 77a5bd3..031a397 100644
--- a/src/system/SystemPacketBuffer.h
+++ b/src/system/SystemPacketBuffer.h
@@ -124,7 +124,7 @@
  *      environment, e.g. from LwIP pbuf target pools, from the standard C library heap, from an internal buffer pool. In the
  *      simple pool case, the size of the data buffer is PacketBuffer::kBlockSize.
  *
- *      PacketBuffer objects may be chained to accomodate larger payloads.  Chaining, however, is not transparent, and users of the
+ *      PacketBuffer objects may be chained to accommodate larger payloads.  Chaining, however, is not transparent, and users of the
  *      class must explicitly decide to support chaining.  Examples of classes written with chaining support are as follows:
  *
  *          @ref chip::chipTLVReader
@@ -615,7 +615,7 @@
      * @brief The PacketBufferHandle's ownership is transferred to the caller.
      *
      * @note This should only be used in low-level code. The caller owns one counted reference to the \c PacketBuffer
-     *       and is reponsible for managing it safely.
+     *       and is responsible for managing it safely.
      *
      * @note The ref-qualifier `&&` requires the caller to use `std::move` to emphasize that ownership is
      *       moved out of this handle.
@@ -778,7 +778,7 @@
 {
 public:
     /**
-     * Constructs a BufferWriter that writes into a packet buffer, using all avaiable space.
+     * Constructs a BufferWriter that writes into a packet buffer, using all available space.
      *
      *  @param[in]  aPacket  A handle to PacketBuffer, to be used as backing store for the BufferWriter.
      */
diff --git a/src/system/tests/TestSystemPacketBuffer.cpp b/src/system/tests/TestSystemPacketBuffer.cpp
index 84922d9..ed34844 100644
--- a/src/system/tests/TestSystemPacketBuffer.cpp
+++ b/src/system/tests/TestSystemPacketBuffer.cpp
@@ -531,7 +531,7 @@
  *               without specifying the head of the buffer chain. Otherwise,
  *               test SetDataLength with one buffer being down the chain and the
  *               other one being passed as the head of the chain. After calling
- *               the method verify that data lenghts were correctly adjusted.
+ *               the method verify that data lengths were correctly adjusted.
  */
 void PacketBufferTest::CheckSetDataLength(nlTestSuite * inSuite, void * inContext)
 {
diff --git a/src/transport/CryptoContext.cpp b/src/transport/CryptoContext.cpp
index b76c53e..c78bf8b 100644
--- a/src/transport/CryptoContext.cpp
+++ b/src/transport/CryptoContext.cpp
@@ -184,7 +184,7 @@
     KeyUsage usage = kR2IKey;
 
     // Message is encrypted before sending. If the secure session was created by session
-    // initiator, we'll use I2R key to encrypt the message that's being transmittted.
+    // initiator, we'll use I2R key to encrypt the message that's being transmitted.
     // Otherwise, we'll use R2I key, as the responder is sending the message.
     if (mSessionRole == SessionRole::kInitiator)
     {
diff --git a/src/transport/PairingSession.cpp b/src/transport/PairingSession.cpp
index c19d425..cbbd8bc 100644
--- a/src/transport/PairingSession.cpp
+++ b/src/transport/PairingSession.cpp
@@ -53,7 +53,7 @@
 
     ChipLogDetail(SecureChannel, "Found MRP parameters in the message");
 
-    // Both TLV elements in the strucutre are optional. If the first element is present, process it and move
+    // Both TLV elements in the structure are optional. If the first element is present, process it and move
     // the TLV reader to the next element.
     if (TLV::TagNumFromTag(tlvReader.GetTag()) == 1)
     {
diff --git a/src/transport/PairingSession.h b/src/transport/PairingSession.h
index 889cbb7..22e1336 100644
--- a/src/transport/PairingSession.h
+++ b/src/transport/PairingSession.h
@@ -72,7 +72,7 @@
      *   Derive a secure session from the paired session. The API will return error
      *   if called before pairing is established.
      *
-     * @param session     Referene to the secure session that will be
+     * @param session     Reference to the secure session that will be
      *                    initialized once pairing is complete
      * @param role        Role of the new session (initiator or responder)
      * @return CHIP_ERROR The result of session derivation
diff --git a/src/transport/raw/UDP.h b/src/transport/raw/UDP.h
index 2ea712c..fcdc624 100644
--- a/src/transport/raw/UDP.h
+++ b/src/transport/raw/UDP.h
@@ -19,7 +19,7 @@
 /**
  *    @file
  *      This file defines the CHIP Connection object that maintains a UDP connection.
- *      It binds to any avaiable local addr and port and begins listening.
+ *      It binds to any available local addr and port and begins listening.
  *
  */
 
diff --git a/src/transport/raw/tests/TestTCP.cpp b/src/transport/raw/tests/TestTCP.cpp
index da743c1..787a1ed2 100644
--- a/src/transport/raw/tests/TestTCP.cpp
+++ b/src/transport/raw/tests/TestTCP.cpp
@@ -393,7 +393,7 @@
     NL_TEST_ASSERT(inSuite, err == CHIP_NO_ERROR);
     NL_TEST_ASSERT(inSuite, gMockTransportMgrDelegate.mReceiveHandlerCallCount == 1);
 
-    // Test a message in a chain of three packet buffers. The message length is split accross buffers.
+    // Test a message in a chain of three packet buffers. The message length is split across buffers.
     gMockTransportMgrDelegate.mReceiveHandlerCallCount = 0;
     NL_TEST_ASSERT(inSuite, testData[0].Init((const uint16_t[]){ 1, 122, 123, 0 }));
     err = tcp.ProcessReceivedBuffer(lEndPoint, lPeerAddress, std::move(testData[0].mHandle));
diff --git a/src/transport/retransmit/Cache.h b/src/transport/retransmit/Cache.h
index 8c4251c..5f2d7d5 100644
--- a/src/transport/retransmit/Cache.h
+++ b/src/transport/retransmit/Cache.h
@@ -50,7 +50,7 @@
  * PayloadType MUST provide a way to reference count, as the data will
  * preserved until the cache is freed:
  *
- *    PayloadType chip::Retransmit::Aquire(PayloadType&);
+ *    PayloadType chip::Retransmit::Acquire(PayloadType&);
  *    chip::Retransmit::Release(PayloadType&);
  */
 template <typename KeyType, typename PayloadType, size_t N>
diff --git a/src/transport/retransmit/tests/TestCache.cpp b/src/transport/retransmit/tests/TestCache.cpp
index 058688d..aac0b42 100644
--- a/src/transport/retransmit/tests/TestCache.cpp
+++ b/src/transport/retransmit/tests/TestCache.cpp
@@ -53,23 +53,23 @@
     void Acquire(int value)
     {
         NL_TEST_ASSERT(mSuite, (value > 0) && value < kMaxPayloadValue);
-        mAquired.set(static_cast<size_t>(value));
+        mAcquired.set(static_cast<size_t>(value));
     }
 
     void Release(int value)
     {
         NL_TEST_ASSERT(mSuite, (value > 0) && value < kMaxPayloadValue);
-        NL_TEST_ASSERT(mSuite, mAquired.test(static_cast<size_t>(value)));
-        mAquired.reset(static_cast<size_t>(value));
+        NL_TEST_ASSERT(mSuite, mAcquired.test(static_cast<size_t>(value)));
+        mAcquired.reset(static_cast<size_t>(value));
     }
 
-    size_t Count() const { return mAquired.count(); }
+    size_t Count() const { return mAcquired.count(); }
 
-    bool IsAquired(int value) const { return mAquired.test(static_cast<size_t>(value)); }
+    bool IsAcquired(int value) const { return mAcquired.test(static_cast<size_t>(value)); }
 
 private:
     nlTestSuite * mSuite;
-    std::bitset<kMaxPayloadValue> mAquired;
+    std::bitset<kMaxPayloadValue> mAcquired;
 };
 
 IntPayloadTracker gPayloadTracker;
@@ -109,7 +109,7 @@
 
 void TestNoOp(nlTestSuite * inSuite, void * inContext)
 {
-    // unused address cache should not do any aquire/release at any time
+    // unused address cache should not do any Acquire/release at any time
     NL_TEST_ASSERT(inSuite, gPayloadTracker.Count() == 0);
     {
         TestableCache<int, int, 20> test;
@@ -212,12 +212,12 @@
     NL_TEST_ASSERT(inSuite, gPayloadTracker.Count() == 2);
 
     // keys 1 and 3 remain
-    NL_TEST_ASSERT(inSuite, gPayloadTracker.IsAquired(1));
-    NL_TEST_ASSERT(inSuite, gPayloadTracker.IsAquired(4));
+    NL_TEST_ASSERT(inSuite, gPayloadTracker.IsAcquired(1));
+    NL_TEST_ASSERT(inSuite, gPayloadTracker.IsAcquired(4));
 
     NL_TEST_ASSERT(inSuite, test.Remove(3) == CHIP_NO_ERROR);
-    NL_TEST_ASSERT(inSuite, gPayloadTracker.IsAquired(1));
-    NL_TEST_ASSERT(inSuite, !gPayloadTracker.IsAquired(4));
+    NL_TEST_ASSERT(inSuite, gPayloadTracker.IsAcquired(1));
+    NL_TEST_ASSERT(inSuite, !gPayloadTracker.IsAcquired(4));
 }
 
 void FindMatching(nlTestSuite * inSuite, void * inContext)
diff --git a/zzz_generated/chip-tool/zap-generated/test/Commands.h b/zzz_generated/chip-tool/zap-generated/test/Commands.h
index 4d4c964..9a32144 100644
--- a/zzz_generated/chip-tool/zap-generated/test/Commands.h
+++ b/zzz_generated/chip-tool/zap-generated/test/Commands.h
@@ -10871,8 +10871,8 @@
             err = TestCheckOnOffAttributeValueIsTrueAfterOnCommand_2();
             break;
         case 3:
-            ChipLogProgress(chipTool, " ***** Test Step 3 : Color Loop Set Command - Set all Attributs\n");
-            err = TestColorLoopSetCommandSetAllAttributs_3();
+            ChipLogProgress(chipTool, " ***** Test Step 3 : Color Loop Set Command - Set all Attributes\n");
+            err = TestColorLoopSetCommandSetAllAttributes_3();
             break;
         case 4:
             ChipLogProgress(chipTool, " ***** Test Step 4 : Check ColorLoopDirection Value\n");
@@ -11092,7 +11092,7 @@
         NextTest();
     }
 
-    CHIP_ERROR TestColorLoopSetCommandSetAllAttributs_3()
+    CHIP_ERROR TestColorLoopSetCommandSetAllAttributes_3()
     {
         const chip::EndpointId endpoint = mEndpointId.HasValue() ? mEndpointId.Value() : 1;
         using RequestType               = chip::app::Clusters::ColorControl::Commands::ColorLoopSet::Type;
diff --git a/examples/minimal-mdns/advertiser.cpp b/examples/minimal-mdns/advertiser.cpp
index 8e4ecc3..78b811f 100644
--- a/examples/minimal-mdns/advertiser.cpp
+++ b/examples/minimal-mdns/advertiser.cpp
@@ -48,7 +48,7 @@
     Optional<uint16_t> deviceType;
     Optional<const char *> deviceName;
 
     // commisionable node params
     uint8_t shortDiscriminator                 = 52;
     uint16_t longDiscriminator                 = 840;
     Dnssd::CommissioningMode commissioningMode = Dnssd::CommissioningMode::kDisabled;
@@ -68,16 +68,16 @@
 constexpr uint16_t kOptionEnableIpV4      = '4';
 constexpr uint16_t kOptionAdvertisingMode = 'm';
 
-constexpr uint16_t kOptionCommisioningShordDiscriminator = 's';
-constexpr uint16_t kOptionCommisioningLongDiscriminaotr  = 'l';
-constexpr uint16_t kOptionCommisioningVendorId           = 0x100; // v is used by 'version'
-constexpr uint16_t kOptionCommisioningProductId          = 'p';
-constexpr uint16_t kOptionCommisioningPairingInstr       = 0x200; // Just use the long format
-constexpr uint16_t kOptionCommisioningPairingHint        = 0x300;
-constexpr uint16_t kOptionCommisioningDeviceType         = 0x400;
-constexpr uint16_t kOptionCommisioningDeviceName         = 0x500;
-constexpr uint16_t kOptionCommisioningMode               = 0x600;
-constexpr uint16_t kOptionCommisioningRotatingId         = 0x700;
+constexpr uint16_t kOptionCommissioningShortDiscriminator = 's';
+constexpr uint16_t kOptionCommissioningLongDiscriminaotr  = 'l';
+constexpr uint16_t kOptionCommissioningVendorId           = 0x100; // v is used by 'version'
+constexpr uint16_t kOptionCommissioningProductId          = 'p';
+constexpr uint16_t kOptionCommissioningPairingInstr       = 0x200; // Just use the long format
+constexpr uint16_t kOptionCommissioningPairingHint        = 0x300;
+constexpr uint16_t kOptionCommissioningDeviceType         = 0x400;
+constexpr uint16_t kOptionCommissioningDeviceName         = 0x500;
+constexpr uint16_t kOptionCommissioningMode               = 0x600;
+constexpr uint16_t kOptionCommissioningRotatingId         = 0x700;
 
 constexpr uint16_t kOptionOperationalFabricId = 'f';
 constexpr uint16_t kOptionOperationalNodeId   = 'n';
@@ -110,19 +110,19 @@
             return false;
         }
         return true;
-    case kOptionCommisioningShordDiscriminator:
+    case kOptionCommissioningShortDiscriminator:
         gOptions.shortDiscriminator = static_cast<uint8_t>(atoi(aValue));
         return true;
-    case kOptionCommisioningLongDiscriminaotr:
+    case kOptionCommissioningLongDiscriminaotr:
         gOptions.longDiscriminator = static_cast<uint16_t>(atoi(aValue));
         return true;
-    case kOptionCommisioningVendorId:
+    case kOptionCommissioningVendorId:
         gOptions.vendorId = Optional<uint16_t>::Value(static_cast<uint16_t>(atoi(aValue)));
         return true;
-    case kOptionCommisioningProductId:
+    case kOptionCommissioningProductId:
         gOptions.productId = Optional<uint16_t>::Value(static_cast<uint16_t>(atoi(aValue)));
         return true;
-    case kOptionCommisioningMode:
+    case kOptionCommissioningMode:
         cm = static_cast<uint8_t>(atoi(aValue));
         if (cm == 1)
         {
@@ -133,19 +133,19 @@
             gOptions.commissioningMode = Dnssd::CommissioningMode::kEnabledEnhanced;
         }
         return true;
-    case kOptionCommisioningDeviceType:
+    case kOptionCommissioningDeviceType:
         gOptions.deviceType = Optional<uint16_t>::Value(static_cast<uint16_t>(atoi(aValue)));
         return true;
-    case kOptionCommisioningDeviceName:
+    case kOptionCommissioningDeviceName:
         gOptions.deviceName = Optional<const char *>::Value(static_cast<const char *>(aValue));
         return true;
-    case kOptionCommisioningRotatingId:
+    case kOptionCommissioningRotatingId:
         gOptions.rotatingId = Optional<const char *>::Value(static_cast<const char *>(aValue));
         return true;
-    case kOptionCommisioningPairingInstr:
+    case kOptionCommissioningPairingInstr:
         gOptions.pairingInstr = Optional<const char *>::Value(static_cast<const char *>(aValue));
         return true;
-    case kOptionCommisioningPairingHint:
+    case kOptionCommissioningPairingHint:
         gOptions.pairingHint = Optional<uint16_t>::Value(static_cast<uint16_t>(atoi(aValue)));
         return true;
     case kOptionOperationalFabricId:
@@ -174,16 +174,16 @@
 #endif
     { "advertising-mode", kArgumentRequired, kOptionAdvertisingMode },
 
-    { "short-discriminator", kArgumentRequired, kOptionCommisioningShordDiscriminator },
-    { "long-discriminator", kArgumentRequired, kOptionCommisioningLongDiscriminaotr },
-    { "vendor-id", kArgumentRequired, kOptionCommisioningVendorId },
-    { "product-id", kArgumentRequired, kOptionCommisioningProductId },
-    { "commissioning-mode", kNoArgument, kOptionCommisioningMode },
-    { "device-type", kArgumentRequired, kOptionCommisioningDeviceType },
-    { "device-name", kArgumentRequired, kOptionCommisioningDeviceName },
-    { "rotating-id", kArgumentRequired, kOptionCommisioningRotatingId },
-    { "pairing-instruction", kArgumentRequired, kOptionCommisioningPairingInstr },
-    { "pairing-hint", kArgumentRequired, kOptionCommisioningPairingHint },
+    { "short-discriminator", kArgumentRequired, kOptionCommissioningShortDiscriminator },
+    { "long-discriminator", kArgumentRequired, kOptionCommissioningLongDiscriminaotr },
+    { "vendor-id", kArgumentRequired, kOptionCommissioningVendorId },
+    { "product-id", kArgumentRequired, kOptionCommissioningProductId },
+    { "commissioning-mode", kNoArgument, kOptionCommissioningMode },
+    { "device-type", kArgumentRequired, kOptionCommissioningDeviceType },
+    { "device-name", kArgumentRequired, kOptionCommissioningDeviceName },
+    { "rotating-id", kArgumentRequired, kOptionCommissioningRotatingId },
+    { "pairing-instruction", kArgumentRequired, kOptionCommissioningPairingInstr },
+    { "pairing-hint", kArgumentRequired, kOptionCommissioningPairingHint },
 
     { "fabric-id", kArgumentRequired, kOptionOperationalFabricId },
     { "node-id", kArgumentRequired, kOptionOperationalNodeId },
@@ -201,15 +201,15 @@
                              "        Advertise in this mode (operational or commissionable-node or commissioner).\n"
                              "  --short-discriminator <value>\n"
                              "  -s <value>\n"
-                             "        Commisioning/commisionable short discriminator.\n"
+                             "        Commissioning/commissionable short discriminator.\n"
                              "  --long-discriminator <value>\n"
                              "  -l <value>\n"
-                             "        Commisioning/commisionable long discriminator.\n"
+                             "        Commissioning/commissionable long discriminator.\n"
                              "  --vendor-id <value>\n"
-                             "        Commisioning/commisionable vendor id.\n"
+                             "        Commissioning/commissionable vendor id.\n"
                              "  --product-id <value>\n"
                              "  -p <value>\n"
-                             "        Commisioning/commisionable product id.\n"
+                             "        Commissioning/commissionable product id.\n"
                              "  --commissioning-mode <value>\n"
                              "        Commissioning Mode (0=disabled, 1=basic, 2=enhanced).\n"
                              "  --device-type <value>\n"
@@ -219,9 +219,9 @@
                              "  --rotating-id <value>\n"
                              "        Rotating Id.\n"
                              "  --pairing-instruction <value>\n"
-                             "        Commisionable pairing instruction.\n"
+                             "        Commissionable pairing instruction.\n"
                              "  --pairing-hint <value>\n"
-                             "        Commisionable pairing hint.\n"
+                             "        Commissionable pairing hint.\n"
                              "  --fabric-id <value>\n"
                              "  -f <value>\n"
                              "        Operational fabric id.\n"
@@ -48,7 +48,7 @@
     Optional<const char *> deviceName;
 
-    // commisionable node params
+    // commissionable node params
     uint8_t shortDiscriminator                 = 52;
     uint16_t longDiscriminator                 = 840;
diff --git a/src/platform/nxp/k32w/k32w0/BLEManagerImpl.cpp b/src/platform/nxp/k32w/k32w0/BLEManagerImpl.cpp
index 69cbda3..c1d0c7b 100644
--- a/src/platform/nxp/k32w/k32w0/BLEManagerImpl.cpp
+++ b/src/platform/nxp/k32w/k32w0/BLEManagerImpl.cpp
@@ -70,7 +70,7 @@
 /* Timeout of BLE commands */
 #define CHIP_BLE_KW_EVNT_TIMEOUT 1000
 
 /** BLE advertisment state changed */
 #define CHIP_BLE_KW_EVNT_ADV_CHANGED 0x0001
 /** BLE advertisement command failed */
 #define CHIP_BLE_KW_EVNT_ADV_FAILED 0x0002
@@ -1545,7 +1545,7 @@
 {
     if (sInstance.mFlags.Has(Flags::kFastAdvertisingEnabled))
     {
-        ChipLogDetail(DeviceLayer, "bleAdv Timeout : Start slow advertisment");
+        ChipLogDetail(DeviceLayer, "bleAdv Timeout : Start slow advertisement");
 
         sInstance.mFlags.Clear(Flags::kFastAdvertisingEnabled);
         // stop advertiser, change interval and restart it;
@@ -70,7 +70,7 @@
 #define CHIP_BLE_KW_EVNT_TIMEOUT 1000
 
-/** BLE advertisment state changed */
+/** BLE advertisement state changed */
 #define CHIP_BLE_KW_EVNT_ADV_CHANGED 0x0001
 /** BLE advertisement command failed */